using Kentico.CMS.TreeEngine; 
using Kentico.CMS.DataEngine; 
using Kentico.CMS.MetadataEngine; 
using System.IO; 
using System.Globalization; 
using Kentico.DirectoryUtilities; 
using Kentico.LicenseProvider; 

///<summary>Shared class providing common functions for all pages.</summary>
using Microsoft.VisualBasic;
using System;
using System.Collections;
using System.Configuration;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.UI;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;
namespace Kentico.CMS.CMSDesk {
    public class Functions  { 
        
        ///<summary>Constructor.</summary>
        static Functions() { 
        } 
        
        
        ///<summary>Returns connection string used throughout the application.</summary>
        public static string GetConnectionString() { 
            return ConfigurationSettings.AppSettings[ "CMSConnectionString" ]; 
        } 
        
        
        
        ///<summary>Creates and returns a new, initialized instance of TreeProvider with current user set.</summary>
        public static TreeProvider GetTreeProvider() { 
            TreeProvider tree = new TreeProvider(); 
            
            tree.Connection.ConnectionString = GetConnectionString(); 
            tree.CombineWithDefaultCulture = false; 
            tree.UserID = GetUserID(); 
            return tree; 
        } 
        
        
        
        ///<summary>Returns User ID of the current user.</summary>
        public static int GetUserID() { 
            if ( System.Web.HttpContext.Current.Session[ "CMSUserID" ] == null & HttpContext.Current.User.Identity.IsAuthenticated == true ) { 
                Functions.SetCurrentUserID( System.Web.HttpContext.Current.User.Identity.Name ); 
            } 
            if ( System.Web.HttpContext.Current.Session[ "CMSUserID" ] == null ) { 
                return 0; 
            } 
            else { 
                return System.Convert.ToInt32( System.Web.HttpContext.Current.Session[ "CMSUserID" ] ); 
            } 
        } 
        
        
        
        ///<summary>Returns physical path to the files (documents) directory.</summary>
        public static string GetFilesPath() { 
            return HttpContext.Current.Server.MapPath( ConfigurationSettings.AppSettings[ "CMSFilesFolder" ] ); 
        } 
        
        
        
        ///<summary>Returns physical path to the metadata directory.</summary>
        public static string GetMetadataPath() { 
            return HttpContext.Current.Server.MapPath( ConfigurationSettings.AppSettings[ "CMSMetadataFolder" ] ); 
        } 
        
        
        
        ///<summary>Returns true if the current user is authorized to access the given resource with required permission.</summary>
        ///<param name="resourceName">Resource name.</param>
        ///<param name="permissionName">Permission name.</param>
        public static bool IsAuthorizedPerResource( string resourceName, string permissionName ) { 
            TreeSecurityProvider treeSec = new TreeSecurityProvider( Functions.GetTreeProvider() ); 
            return treeSec.IsAuthorizedPerResource( resourceName, permissionName ); 
        } 
        
        
        
        ///<summary>Returns true if the current user is authorized to access the given node with required permission.</summary>
        ///<param name="path">Node path.</param>
        ///<param name="pathType">Type of the provided path.</param>
        ///<param name="permission">Required permission.</param>
        ///<remarks>This method checks not only the permissions for the given node. Rather, it also checks if the user was granted with specified permission for the CMS.Content resource.</remarks>
        public static bool IsAuthorizedPerNode( string path, TreePathTypeEnum pathType, NodePermissionsEnum permission ) { 
            TreeSecurityProvider treeSec = new TreeSecurityProvider( Functions.GetTreeProvider() ); 
            return treeSec.IsAuthorizedPerNode( path, pathType, permission ); 
        } 
        
        
        
        ///<summary>Returns true if the current user is authorized to access the given class with required permission.</summary>
        ///<param name="className">Class name in format application.class.</param>    
        ///<param name="permissionName">Name of the required permission..</param>
        ///<remarks>This method checks not only the permissions for the given node. Rather, it also checks if the user was granted with specified permission for the CMS.Content resource.</remarks>
        public static bool IsAuthorizedPerClass( string className, string permissionName ) { 
            TreeSecurityProvider treeSec = new TreeSecurityProvider( Functions.GetTreeProvider() ); 
            return treeSec.IsAuthorizedPerClass( className, permissionName ); 
        } 
        
        
        
        ///<summary>Sets current user's ID into a session variable for further use.</summary>
        ///<param name="userName">User name.</param>
        public static void SetCurrentUserID( string userName ) { 
            if ( userName + "" + "" == "" ) { 
                return; 
            } 
            
            GeneralConnection cn = new GeneralConnection( Functions.GetConnectionString() ); 
            object[,] paramsIdent = new object[ 1, 3 ]; 
            DataSet ds = null; 
            
            paramsIdent[ 0, 0 ] = "@UserName"; 
            paramsIdent[ 0, 1 ] = userName; 
            ds = cn.ExecuteQuery( "CMS.User.selectbyusername", paramsIdent ); 
            if ( ds.Tables[ 0 ].Rows.Count > 0 ) { 
                System.Web.HttpContext.Current.Session[ "CMSUserID" ] = ds.Tables[ 0 ].Rows[ 0 ][ "UserID" ]; 
            } 
            else { 
                return; 
            } 
            
            // set preferred culture session
            Functions.GetPreferredUICulture(); 
            Functions.GetPreferredContentCultureCode(); 
        } 
        
        
        
        ///<summary>Redirects user to the "Access Denied" page.</summary>
        ///<param name="resourceName">Name of the resource that cannot be accessed.</param>
        ///<param name="permissionName">Name of the permission that is not allowed.</param>
        public static void RedirectToAccessDenied( string resourceName, string permissionName ) { 
            string basePath = HttpContext.Current.Request.ApplicationPath; 
            if ( basePath.EndsWith( "/" ) ) { 
                basePath = basePath.Substring( 0, basePath.Length - 1 ); 
            } 
            System.Web.HttpContext.Current.Response.Redirect( basePath + "/cmsdesk/accessdenied.aspx?resource=" + resourceName + "&permission=" + permissionName ); 
        } 
        
        
        
        ///<summary>Checks if all folders of the given path exist and if not, it creates them.</summary>
        ///<param name="path">Full disk path of the file including file name.</param>
        ///<param name="startingPath">Starting path where folders can be checked and created.</param>
        public static void EnsureDiskPath( string path, string startingPath ) { 
            DirectoryHelper.EnsureDiskPath( path, startingPath ); 
        } 
        
        
        
        ///<summary>Creates folders and files necessary for friendly URL engine.</summary>
        ///<param name="newAliasPath">Alias path of the newly created document.</param>
        public static void EnsureFriendlyURL( string newAliasPath ) { 
            EnsureFriendlyURL( newAliasPath, "" ); 
        } 
        
        
        
        ///<summary>Moves folders and files necessary for friendly URL engine.</summary>
        ///<param name="newAliasPath">Alias path of the new location parent node.</param>
        ///<param name="oldAliasPath">Alias path of the old document.</param>
        public static void EnsureFriendlyURL( string newAliasPath, string oldAliasPath ) { 
            if ( !( GenerateFriendlyUrlFiles() ) ) { 
                return; 
            } 
            
            string originalNewAliasPath = newAliasPath; 
            
            if ( oldAliasPath == null ) { 
                oldAliasPath = ""; 
            } 
            if ( !( ( newAliasPath.StartsWith( GetCMSWebSiteBaseAliasPath() ) & newAliasPath.Length > GetCMSWebSiteBaseAliasPath().Length ) ) ) { 
                return; 
            } 
            if ( oldAliasPath + "" + "" != "" && !( ( oldAliasPath.StartsWith( GetCMSWebSiteBaseAliasPath() ) & oldAliasPath.Length > GetCMSWebSiteBaseAliasPath().Length ) ) ) { 
                return; 
            } 
            if ( !( IsUsingFriendlyURLs( newAliasPath ) ) ) { 
                return; 
            } 
            // adjust alias paths
            newAliasPath = newAliasPath.Substring( GetCMSWebSiteBaseAliasPath().Length ); 
            if ( oldAliasPath + "" + "" != "" ) { 
                oldAliasPath = oldAliasPath.Substring( GetCMSWebSiteBaseAliasPath().Length ); 
            } 
            if ( Functions.UseMultilingualSupport() & newAliasPath.Split( '/' ).Length > 2 ) { 
                newAliasPath = Functions.RemoveCultureFromAliasPath( newAliasPath ); 
                if ( oldAliasPath.Split( '/' ).Length > 2 ) { 
                    oldAliasPath = Functions.RemoveCultureFromAliasPath( oldAliasPath ); 
                } 
            } 
            // check if the new folder should be created or moved from somewhere else
            if ( oldAliasPath + "" + "" != "" ) { 
                // rename or move existing folder            
                string oldDiskPath = HttpContext.Current.Server.MapPath( GetWebApplicationVirtualPath() ) + Strings.Replace( oldAliasPath, "/", @"\", 1, -1, (Microsoft.VisualBasic.CompareMethod)(0) ); 
                string newDiskPath = HttpContext.Current.Server.MapPath( GetWebApplicationVirtualPath() ) + Strings.Replace( newAliasPath, "/", @"\", 1, -1, (Microsoft.VisualBasic.CompareMethod)(0) ); 
                if ( Directory.Exists( oldDiskPath ) ) { 
                    Functions.EnsureDiskPath( newDiskPath, HttpContext.Current.Server.MapPath( Functions.GetWebApplicationVirtualPath() ) ); 
                    if ( oldDiskPath != newDiskPath ) { 
                        try { 
                            DirectoryHelper.MoveDirectory( oldDiskPath, newDiskPath ); 
                        } 
                        catch ( Exception ex ) { 
                            DirectoryHelper.CopyDirectory( oldDiskPath, newDiskPath ); 
                        } 
                    } 
                } 
                else { 
                    EnsureFriendlyURL( originalNewAliasPath ); 
                } 
                // move attachments folder
                if ( Directory.Exists( Functions.GetFileFolderPath( oldAliasPath + "/NOTHING" ) ) ) { 
                    Functions.EnsureDiskPath( Functions.GetFileFolderPath( newAliasPath + "/NOTHING" ), HttpContext.Current.Server.MapPath( Functions.GetWebApplicationVirtualPath() ) ); 
                    if ( oldAliasPath != newAliasPath ) { 
                        try { 
                            DirectoryHelper.MoveDirectory( Functions.GetFileFolderPath( oldAliasPath + "/NOTHING" ), Functions.GetFileFolderPath( newAliasPath + "/NOTHING" ) ); 
                        } 
                        catch ( Exception ex ) { 
                            DirectoryHelper.CopyDirectory( Functions.GetFileFolderPath( oldAliasPath + "/NOTHING" ), Functions.GetFileFolderPath( newAliasPath + "/NOTHING" ) ); 
                        } 
                    } 
                } 
            } 
            try { 
                string diskPath = HttpContext.Current.Server.MapPath( GetWebApplicationVirtualPath() ) + Strings.Replace( newAliasPath, "/", @"\", 1, -1, (Microsoft.VisualBasic.CompareMethod)(0) ) + @"\default.aspx"; 
                EnsureDiskPath( diskPath, HttpContext.Current.Server.MapPath( Functions.GetWebApplicationVirtualPath() ) ); 
                if ( File.Exists( diskPath ) == false ) { 
                    // Create a file to write to
                    StreamWriter sw = File.CreateText( diskPath ); 
                    sw.WriteLine( "This is an empty ASPX file. It's used by the URL rewriting engine. Please do not remove it." ); 
                    sw.Flush(); 
                    sw.Close(); 
                } 
            } 
            catch  { 
            } 
        } 
        
        
        
        ///<summary>Deletes folders and files used for friendly URLs.</summary>
        ///<param name="aliasPath">Alias path of the node being deleted.</param>
        public static void DeleteFriendlyURL( string aliasPath ) { 
            if ( !( GenerateFriendlyUrlFiles() ) ) { 
                return; 
            } 
            if ( !( ( aliasPath.StartsWith( GetCMSWebSiteBaseAliasPath() ) & aliasPath.Length > GetCMSWebSiteBaseAliasPath().Length ) ) ) { 
                return; 
            } 
            // adjust alias path
            aliasPath = aliasPath.Substring( GetCMSWebSiteBaseAliasPath().Length ); 
            if ( Functions.UseMultilingualSupport() & aliasPath.Split( '/' ).Length > 2 ) { 
                // delete friendly URL only in case that the default culture version is being deleted
                if ( Strings.Trim( Strings.LCase( aliasPath.Split( '/' )[ 1 ] + "" ) ) != Strings.Trim( Strings.LCase( ConfigurationSettings.AppSettings[ "CMSDefaultCultureCode" ] + "" ) ) ) { 
                    return; 
                } 
                else { 
                    aliasPath = Functions.RemoveCultureFromAliasPath( aliasPath ); 
                } 
            } 
            string folderPath = HttpContext.Current.Server.MapPath( GetWebApplicationVirtualPath() ) + Strings.Replace( aliasPath, "/", @"\", 1, -1, (Microsoft.VisualBasic.CompareMethod)(0) ); 
            if ( Directory.Exists( folderPath ) ) { 
                try { 
                    Directory.Delete( folderPath, true ); 
                } 
                catch  { 
                } 
            } 
            // delete the folder in the attachments folder
            if ( Directory.Exists( Functions.GetAttachmentBaseDiskPath() + Strings.Replace( aliasPath, "/", @"\", 1, -1, (Microsoft.VisualBasic.CompareMethod)(0) ) ) ) { 
                try { 
                    Directory.Delete( Functions.GetAttachmentBaseDiskPath() + Strings.Replace( aliasPath, "/", @"\", 1, -1, (Microsoft.VisualBasic.CompareMethod)(0) ), true ); 
                } 
                catch  { 
                } 
            } 
        } 
        
        
        
        ///<summary>Copies existing folders and files for friendly URLs.</summary>
        ///<param name="sourceAliasPath">Source alias path of the node that is being copied.</param>
        ///<param name="targetAliasPath">Target alias path of the parent node.</param>
        public static void CopyFriendlyURL( string sourceAliasPath, string targetAliasPath ) { 
            if ( !( GenerateFriendlyUrlFiles() ) ) { 
                return; 
            } 
            if ( !( ( sourceAliasPath.StartsWith( GetCMSWebSiteBaseAliasPath() ) & sourceAliasPath.Length > GetCMSWebSiteBaseAliasPath().Length & targetAliasPath.StartsWith( GetCMSWebSiteBaseAliasPath() ) & targetAliasPath.Length > GetCMSWebSiteBaseAliasPath().Length ) ) ) { 
                return; 
            } 
            if ( !( IsUsingFriendlyURLs( sourceAliasPath ) ) ) { 
                return; 
            } 
            // adjust alias paths
            sourceAliasPath = sourceAliasPath.Substring( GetCMSWebSiteBaseAliasPath().Length ); 
            targetAliasPath = targetAliasPath.Substring( GetCMSWebSiteBaseAliasPath().Length ); 
            string sourceAliasPathWithoutCulture = null; 
            string targetAliasPathWithoutCulture = null; 
            if ( Functions.UseMultilingualSupport() & sourceAliasPath.Split( '/' ).Length > 2 & targetAliasPath.Split( '/' ).Length > 2 ) { 
                sourceAliasPathWithoutCulture = Functions.RemoveCultureFromAliasPath( sourceAliasPath ); 
                targetAliasPathWithoutCulture = Functions.RemoveCultureFromAliasPath( targetAliasPath ); 
            } 
            else { 
                sourceAliasPathWithoutCulture = sourceAliasPath; 
                targetAliasPathWithoutCulture = targetAliasPath; 
            } 
            string sourceFolderPath = HttpContext.Current.Server.MapPath( GetWebApplicationVirtualPath() ) + Strings.Replace( sourceAliasPathWithoutCulture, "/", @"\", 1, -1, (Microsoft.VisualBasic.CompareMethod)(0) ); 
            string targetFolderPath = HttpContext.Current.Server.MapPath( GetWebApplicationVirtualPath() ) + Strings.Replace( targetAliasPathWithoutCulture, "/", @"\", 1, -1, (Microsoft.VisualBasic.CompareMethod)(0) ); 
            string nodeAlias = sourceFolderPath.Substring( sourceFolderPath.LastIndexOf( @"\" ) + 1 ); 
            if ( Directory.Exists( sourceFolderPath ) ) { 
                try { 
                    EnsureDiskPath( targetFolderPath, HttpContext.Current.Server.MapPath( Functions.GetWebApplicationVirtualPath() ) ); 
                    CopyFolder( sourceFolderPath, targetFolderPath ); 
                } 
                catch ( Exception ex ) { 
                } 
            } 
            // copy folders in the Attachments/files folder if applicable
            if ( Directory.Exists( Functions.GetFileFolderPath( sourceAliasPath + @"\NOTHING" ) ) ) { 
                EnsureDiskPath( Functions.GetFileFolderPath( targetAliasPath ) + @"\nothing.txt", Functions.GetAttachmentBaseDiskPath() ); 
                CopyFolder( Functions.GetFileFolderPath( sourceAliasPath + "/NOTHING" ), Functions.GetFileFolderPath( targetAliasPath + "/NOTHING" ) ); 
            } 
        } 
        
        
        ///<summary>Moves file (attachement).</summary>
        ///<param name="sourceAliasPath">Source alias path.</param>
        ///<param name="targetAliasPath">Target alias path.</param>
        public static void CopyAttachment( string sourceAliasPath, string targetAliasPath ) { 
            TreeProvider tree = Functions.GetTreeProvider(); 
            TreeNode node = tree.SelectSingleNode( sourceAliasPath, TreePathTypeEnum.AliasPath ); 
            if ( node.ClassName.ToLower() != "cms.file" ) { 
                return; 
            } 
            string fileName = System.Convert.ToString( node.GetValue( "FileName" ) ); 
            string sourceFolderPath = Functions.GetFileFolderPath( sourceAliasPath ); 
            string targetFolderPath = Functions.GetFileFolderPath( targetAliasPath ); 
            if ( !( sourceFolderPath.EndsWith( @"\" ) ) ) { 
                sourceFolderPath += @"\"; 
            } 
            if ( !( targetFolderPath.EndsWith( @"\" ) ) ) { 
                targetFolderPath += @"\"; 
            } 
            Functions.EnsureDiskPath( targetFolderPath, Functions.GetAttachmentBaseDiskPath() ); 
            File.Copy( sourceFolderPath + fileName, targetFolderPath + fileName, true ); 
        } 
        
        
        
        ///<summary>Moves file (attachement).</summary>
        ///<param name="oldAliasPath">Old alias path.</param>
        ///<param name="newAliasPath">New alias path.</param>
        public static void MoveAttachment( string oldAliasPath, string newAliasPath ) { 
            TreeProvider tree = Functions.GetTreeProvider(); 
            TreeNode node = tree.SelectSingleNode( newAliasPath, TreePathTypeEnum.AliasPath ); 
            if ( node.ClassName.ToLower() != "cms.file" ) { 
                return; 
            } 
            string fileName = System.Convert.ToString( node.GetValue( "FileName" ) ); 
            string sourceFolderPath = Functions.GetFileFolderPath( oldAliasPath ); 
            string targetFolderPath = Functions.GetFileFolderPath( newAliasPath ); 
            if ( !( sourceFolderPath.EndsWith( @"\" ) ) ) { 
                sourceFolderPath += @"\"; 
            } 
            if ( !( targetFolderPath.EndsWith( @"\" ) ) ) { 
                targetFolderPath += @"\"; 
            } 
            Functions.EnsureDiskPath( targetFolderPath, Functions.GetAttachmentBaseDiskPath() ); 
            File.Move( sourceFolderPath + fileName, targetFolderPath + fileName ); 
        } 
        
        
        
        ///<summary>Returns Web application virtual path.</summary>
        ///<remarks>It uses the CMSWebApplicationVirtualPath configuration parameter. If it's not used, "~/" is returned.</remarks>
        public static string GetWebApplicationVirtualPath() { 
            if ( ConfigurationSettings.AppSettings[ "CMSWebApplicationVirtualPath" ] == null || ConfigurationSettings.AppSettings[ "CMSWebApplicationVirtualPath" ] + "" == "" ) { 
                return "~/."; 
            } 
            else { 
                return ConfigurationSettings.AppSettings[ "CMSWebApplicationVirtualPath" ]; 
            } 
        } 
        
        
        
        ///<summary>Returns web site base alias path from the application configuration.</summary>
        public static string GetCMSWebSiteBaseAliasPath() { 
            return ConfigurationSettings.AppSettings[ "CMSWebSiteBaseAliasPath" ] + ""; 
        } 
        
        
        
        ///<summary>Copies folder including subfolders and all files.</summary>
        ///<param name="sourceFolder">Source folder physical path.</param>
        ///<param name="targetFolder">Target parent folder physical path.</param>
        private static void CopyFolder( string sourceFolder, string targetFolder ) { 
            DirectoryHelper.CopyDirectory( sourceFolder, targetFolder ); 
        } 
        
        
        
        ///<summary>Returns true if node with provided aliasPath uses friendly URLs.</summary>
        ///<param name="aliasPath">Alias path of the document.</param>
        public static bool IsUsingFriendlyURLs( string aliasPath ) { 
            TreeProvider tree = GetTreeProvider(); 
            TreeNode node = tree.SelectSingleNode( aliasPath, TreePathTypeEnum.AliasPath ); 
            if ( node == null ) { 
                return false; 
            } 
            else { 
                if ( MetadataProvider.GetSettingsValue( node.ClassName, "SupportFriendlyURLs" ) == "true" ) { 
                    return true; 
                } 
                else { 
                    return false; 
                } 
            } 
        } 
        
        
        
        ///<summary>Returns true if multilingual support is switched on.</summary>
        public static bool UseMultilingualSupport() { 
            if ( Strings.Trim( Strings.LCase( ConfigurationSettings.AppSettings[ "CMSUseMultilingualSupport" ] + "" ) ) == "true" ) { 
                return true; 
            } 
            else { 
                return false; 
            } 
        } 
        
        
        ///<summary>Removes culture from alias path if you're using multilingual support with hidden culture.</summary>
        public static string RemoveCultureFromAliasPath( string aliasPath ) { 
            if ( UseMultilingualSupport() ) { 
                return aliasPath.Substring( aliasPath.Split( '/' )[ 1 ].Length + 1 ); 
            } 
            else { 
                return aliasPath; 
            } 
        } 
        
        
        
        ///<summary>Returns alias path of the node with required culture.</summary>
        public static string GetMultilingualAliasPath( string idpath, string requiredCulture ) { 
            // get node
            TreeNode node = null; 
            TreeProvider tree = Functions.GetTreeProvider(); 
            TreeNode cultureNode = null; 
            
            // first check if document is placed under some cultureNode or if it is a culture node
            if ( idpath.Split( '/' )[ 1 ] + "" == "" ) { 
                return "/"; 
            } 
            else { 
                node = tree.SelectSingleNode( idpath, TreePathTypeEnum.IDPath ); 
                cultureNode = tree.SelectSingleNode( "/" + idpath.Split( '/' )[ 1 ], TreePathTypeEnum.IDPath ); 
                if ( cultureNode.ClassName.ToLower() == "cms.culture" ) { 
                    // this is culture node - return alias path with required culture
                    return "/" + requiredCulture + Functions.RemoveCultureFromAliasPath( System.Convert.ToString( node.GetValue( "AliasPath" ) ) ); 
                } 
                else { 
                    // this document is placed outside the culture zone - return the actual alias path
                    return System.Convert.ToString( node.GetValue( "AliasPath" ) ); 
                } 
            } 
        } 
        
        
        
        ///<summary>Returns default culture for multilingual support.</summary>
        public static string GetDefaultCulture() { 
            return ConfigurationSettings.AppSettings[ "CMSDefaultCultureCode" ] + ""; 
        } 
        
        
        
        ///<summary>Returns preferred UI culture of the current user.</summary>
        public static CultureInfo GetPreferredUICulture() { 
            if ( Functions.GetUserID() == 0 ) { 
                if ( GetDefaultCulture() + "" == "" ) { 
                    HttpContext.Current.Session[ "CMSUserPreferredUICulture" ] = System.Threading.Thread.CurrentThread.CurrentCulture; 
                } 
                else { 
                    HttpContext.Current.Session[ "CMSUserPreferredUICulture" ] = new CultureInfo( GetDefaultCulture() ); 
                } 
            } 
            if ( HttpContext.Current.Session[ "CMSUserPreferredUICulture" ] == null ) { 
                // get preferred language
                DataClass userObj = null; 
                TreeProvider tree = Functions.GetTreeProvider(); 
                
                userObj = new DataClass( "cms.user", Functions.GetUserID(), tree.Connection ); 
                if ( Strings.Trim( System.Convert.ToString( userObj.GetValue( "PreferredUICultureCode" ) ) + "" ) + "" != "" ) { 
                    HttpContext.Current.Session[ "CMSUserPreferredUICulture" ] = new CultureInfo( Strings.Trim( System.Convert.ToString( userObj.GetValue( "PreferredUICultureCode" ) ) + "" ) ); 
                } 
                else { 
                    HttpContext.Current.Session[ "CMSUserPreferredUICulture" ] = System.Threading.Thread.CurrentThread.CurrentCulture; 
                } 
            } 
            System.Threading.Thread.CurrentThread.CurrentCulture = ( ( CultureInfo )( HttpContext.Current.Session[ "CMSUserPreferredUICulture" ] ) ); 
            System.Threading.Thread.CurrentThread.CurrentUICulture = ( ( CultureInfo )( HttpContext.Current.Session[ "CMSUserPreferredUICulture" ] ) ); 
            return ( ( CultureInfo )( HttpContext.Current.Session[ "CMSUserPreferredUICulture" ] ) ); 
        } 
        
        
        
        ///<summary>Returns the code of the preferred content culture of the current user.</summary>
        public static string GetPreferredContentCultureCode() { 
            if ( Functions.GetUserID() == 0 ) { 
                return null; 
            } 
            if ( HttpContext.Current.Session[ "CMSPreferredCulture" ] == null ) { 
                HttpContext.Current.Session[ "CMSPreferredCulture" ] = ConfigurationSettings.AppSettings[ "CMSDefaultCultureCode" ] + ""; 
                HttpContext.Current.Response.Cookies.Add( new HttpCookie( "CMSPreferredCulture", ConfigurationSettings.AppSettings[ "CMSDefaultCultureCode" ] + "" ) ); 
                // get preferred language
                DataClass userObj = null; 
                TreeProvider tree = Functions.GetTreeProvider(); 
                
                userObj = new DataClass( "cms.user", Functions.GetUserID(), tree.Connection ); 
                if ( Strings.Trim( System.Convert.ToString( userObj.GetValue( "PreferredContentCultureCode" ) ) + "" ) + "" != "" ) { 
                    HttpContext.Current.Session[ "CMSPreferredCulture" ] = Strings.Trim( System.Convert.ToString( userObj.GetValue( "PreferredContentCultureCode" ) ) + "" ); 
                    HttpContext.Current.Response.Cookies.Add( new HttpCookie( "CMSPreferredCulture", Strings.Trim( System.Convert.ToString( userObj.GetValue( "PreferredContentCultureCode" ) ) + "" ) ) ); 
                } 
            } 
            return System.Convert.ToString( HttpContext.Current.Session[ "CMSPreferredCulture" ] ); 
        } 
        
        
        
        ///<summary>Returns starting IDPath from the user profile of the current user. If no path is specified, root node ("/") is returned.</summary>
        public static string GetUsersStartingPath() { 
            string idpath = "/"; 
            // try to get starting path from user profile
            TreeProvider tree = null; 
            DataClass userObj = null; 
            TreeNode node = null; 
            
            tree = Functions.GetTreeProvider(); 
            userObj = new DataClass( "cms.user", Functions.GetUserID(), tree.Connection ); 
            if ( userObj.IsEmpty() ) { 
                return "/"; 
            } 
            if ( Strings.Trim( System.Convert.ToString( userObj.GetValue( "StartingAliasPath" ) ) + "" ) + "" != "" ) { 
                node = tree.SelectSingleNode( Strings.Trim( System.Convert.ToString( userObj.GetValue( "StartingAliasPath" ) ) + "" ), TreePathTypeEnum.AliasPath ); 
                if ( !( node == null ) ) { 
                    idpath = System.Convert.ToString( node.GetValue( "idpath" ) ); 
                } 
                else { 
                    throw new ApplicationException( "Invalid starting path." ); 
                } 
            } 
            
            return idpath; 
        } 
        
        
        
        ///<summary>Returns starting AliasPath from the user profile of the current user. If no path is specified, root node ("/") is returned.</summary>
        public static string GetUsersStartingAliasPath() { 
            string aliaspath = ""; 
            
            // try to get starting path from user profile
            TreeProvider tree = null; 
            DataClass userObj = null; 
            TreeNode node = null; 
            
            tree = Functions.GetTreeProvider(); 
            userObj = new DataClass( "cms.user", Functions.GetUserID(), tree.Connection ); 
            if ( !( userObj.IsEmpty() ) ) { 
                aliaspath = Strings.Trim( System.Convert.ToString( userObj.GetValue( "StartingAliasPath" ) ) + "" ); 
            } 
            if ( aliaspath + "" == "" ) { 
                aliaspath = "/"; 
            } 
            
            return aliaspath; 
        } 
        
        
        
        ///<summary>Returns node of the specified IDPath and culture.</summary>
        ///<param name="idPath">IDPath of the default culture version of the node.</param>
        ///<param name="cultureCode">Culture code of the required culture version.</param>
        ///<remarks>If node is not available for specified culture, it returns nothing (null). If multilingual support is not used or no culture code is provided, it returns the node with specified idpath.</remarks>
        public static TreeNode GetNodeByIDPathAndCulture( string idPath, string cultureCode ) { 
            TreeProvider tree = null; 
            TreeNode node = null; 
            string aliaspath = null; 
            
            tree = Functions.GetTreeProvider(); 
            node = tree.SelectSingleNode( idPath, TreePathTypeEnum.IDPath ); 
            if ( Functions.UseMultilingualSupport() & cultureCode + "" + "" != "" ) { 
                aliaspath = System.Convert.ToString( node.GetValue( "AliasPath" ) ); 
                node = tree.SelectSingleNode( "/" + cultureCode + Functions.RemoveCultureFromAliasPath( aliaspath ), TreePathTypeEnum.AliasPath ); 
            } 
            return node; 
        } 
        
        
        
        ///<summary>Returns true if current installation of Kentico CMS is an Express Edition.</summary>
        ///<param name="featureName">Name of the requested feature.</param>
        public static bool RedirectExpressEdition( string featureName ) { 
            if ( LicenseManager.GetProductCode() == "CX" ) { 
                string basePath = HttpContext.Current.Request.ApplicationPath; 
                if ( basePath.EndsWith( "/" ) ) { 
                    basePath = basePath.Substring( 0, basePath.Length - 1 ); 
                } 
                System.Web.HttpContext.Current.Response.Redirect( basePath + "/cmsdesk/editionerror.aspx?feature=" + featureName ); 
            } 
            return false;
        } 
        
        
        
        ///<summary>Returns required value from the class definition.</summary>
        ///<param name="classId">Class ID.</param>
        ///<param name="columnName">Column name whose value should be returned.</param>
        public static object GetClassDRValue( int classId, string columnName ) { 
            return ClassInformationProvider.GetClassRow( classId, GetTreeProvider() )[columnName]; 
        } 
        
        
        
        ///<summary>Deletes attachment.</summary>
        ///<param name="aliasPath">Alias path of the attachment.</param>
        public static void DeleteAttachment( string aliasPath ) { 
            TreeProvider tree = GetTreeProvider(); 
            TreeNode node = null; 
            string diskPath = null; 
            
            node = tree.SelectSingleNode( aliasPath, TreePathTypeEnum.AliasPath ); 
            if ( !( node == null ) ) { 
                if ( node.ClassName.ToLower() == "cms.file" ) { 
                    diskPath = GetFileFolderPath( aliasPath ); 
                    if ( !( diskPath.EndsWith( @"\" ) ) ) { 
                        diskPath += @"\"; 
                    } 
                    diskPath = diskPath + System.Convert.ToString( node.GetValue( "FileName" ) ); 
                    if ( File.Exists( diskPath ) ) { 
                        try { 
                            File.Delete( diskPath ); 
                        } 
                        catch ( Exception ex ) { 
                        } 
                    } 
                } 
            } 
        } 
        
        
        ///<summary>Deletes attachment specified by its alias path and file name. This method is used when deleted file is destroyed.</summary>
        ///<param name="aliasPath">Alias path of the attachment.</param>
        ///<param name="fileName">File name of the attachment.</param>
        public static void DeleteAttachment( string aliasPath, string fileName ) { 
            string diskPath = null; 
            
            diskPath = GetFileFolderPath( aliasPath ); 
            if ( !( diskPath.EndsWith( @"\" ) ) ) { 
                diskPath += @"\"; 
            } 
            diskPath = diskPath + fileName; 
            if ( File.Exists( diskPath ) ) { 
                try { 
                    File.Delete( diskPath ); 
                } 
                catch ( Exception ex ) { 
                } 
            } 
        } 
        
        
        
        ///<summary>Returns base disk path of the attachments folder.</summary>
        public static string GetAttachmentBaseDiskPath() { 
            if ( !( ConfigurationSettings.AppSettings[ "CMSAttachmentsFolder" ] == null ) && ConfigurationSettings.AppSettings[ "CMSAttachmentsFolder" ] + "" != "" ) { 
                // attachments folder is specified
                if ( ConfigurationSettings.AppSettings[ "CMSAttachmentsFolder" ].StartsWith( "/" ) ) { 
                    // it's a virtual folder
                    return HttpContext.Current.Server.MapPath( ConfigurationSettings.AppSettings[ "CMSAttachmentsFolder" ] ); 
                } 
                else { 
                    // it's a physical path
                    return ConfigurationSettings.AppSettings[ "CMSAttachmentsFolder" ]; 
                } 
            } 
            else { 
                // attachments folder is not specified - use web path instead
                if ( GetWebApplicationVirtualPath() + "" != "" ) { 
                    return HttpContext.Current.Server.MapPath( GetWebApplicationVirtualPath() ); 
                } 
                else { 
                    return HttpContext.Current.Server.MapPath( "~/." ); 
                } 
            } 
        } 
        
        
        
        ///<summary>Returns folder path of the file specified by alias path.</summary>
        ///<param name="aliasPath">Alias Path of the node.</param>
        public static string GetFileFolderPath( string aliasPath ) { 
            string result = ""; 
            
            aliasPath = Functions.RemoveCultureFromAliasPath( aliasPath ); 
            if ( aliasPath.ToLower().StartsWith( "/files" ) ) { 
                // this is a files folder
                if ( ( !( ConfigurationSettings.AppSettings[ "CMSFilesFolder" ] == null ) ) && ( ConfigurationSettings.AppSettings[ "CMSFilesFolder" ] + "" != "" ) ) { 
                    result = System.Web.HttpContext.Current.Server.MapPath( ConfigurationSettings.AppSettings[ "CMSFilesFolder" ] ); 
                } 
                else { 
                    result = System.Web.HttpContext.Current.Server.MapPath( "~/files" ); 
                } 
                // replace "/files"
                aliasPath = aliasPath.Substring( "/files".Length ); 
            } 
            else { 
                result = GetAttachmentBaseDiskPath(); 
            } 
            if ( result.EndsWith( @"\" ) ) { 
                result = result.Substring( 0, result.Length - 1 ); 
            } 
            // remove last part of the alias path (the file name)
            string[] pathSplit = aliasPath.Split( '/' ); 
            aliasPath = aliasPath.Substring( 0, aliasPath.Length - pathSplit[ pathSplit.Length - 1 ].Length ); 
            if ( aliasPath.EndsWith( "/" ) ) { 
                aliasPath = aliasPath.Substring( 0, aliasPath.Length - 1 ); 
            } 
            // add alias path
            result += aliasPath.Replace( '/', '\\' ); 
            return result; 
        } 
        
        
        
        ///<summary>Tries to create a new file and and a new directory and returns error message if it fails.</summary>
        public static string CheckSystemPermissions() { 
            string errorMessage = ""; 
            
            // check file system permissions        
            try { 
                string path = HttpContext.Current.Server.MapPath( "~/testsystemsettings_" + HttpContext.Current.Session.SessionID + ".txt" ); 
                StreamWriter sw = File.CreateText( path ); 
                sw.WriteLine( "Test of permissions." ); 
                sw.Flush(); 
                sw.Close(); 
                File.Delete( path ); 
                path = HttpContext.Current.Server.MapPath( "~/testsystemsettings_" + HttpContext.Current.Session.SessionID ); 
                DirectoryHelper.CreateDirectory( path ); 
                Directory.Delete( path ); 
            } 
            catch ( Exception ex ) { 
                errorMessage += Strings.Replace( ResMan.GetString( "CheckSystemPermissions.ErrorDiskAccess" ), "#ACCOUNT#", System.Security.Principal.WindowsIdentity.GetCurrent().Name, 1, -1, (Microsoft.VisualBasic.CompareMethod)(0) ) + " " + HttpContext.Current.Server.MapPath( "~/." ); 
            } 
            return errorMessage; 
        } 
        
        
        
        ///<summary>Returns true if helper files for friendly URLs support should be generated in the file system.</summary>
        public static bool GenerateFriendlyUrlFiles() { 
            if ( ( !( ConfigurationSettings.AppSettings[ "CMSGenerateFriendlyUrlFiles" ] == null ) ) && ConfigurationSettings.AppSettings[ "CMSGenerateFriendlyUrlFiles" ].Trim().ToLower() == "false" ) { 
                return false; 
            } 
            else { 
                return true; 
            } 
        } 
        
        
        
        ///<summary>Adds the postfix of the generated URLs according to the CMSFriendlyURLStyle web.config parameter value.</summary>
        ///<param name="aliasPath">Alias path that should be (optionally) converted.</param>
        public static string GetUrlForAliasPath( string aliasPath ) { 
            if ( ( !( ConfigurationSettings.AppSettings[ "CMSFriendlyURLStyle" ] == null ) ) && ConfigurationSettings.AppSettings[ "CMSFriendlyURLStyle" ].Trim().ToLower() + "" != "" ) { 
                if ( aliasPath == "/" | aliasPath == "~" | aliasPath == "~/" | aliasPath == "~/." ) { 
                    return aliasPath; 
                } 
                else { 
                    return aliasPath + ConfigurationSettings.AppSettings[ "CMSFriendlyURLStyle" ].Trim().ToLower(); 
                } 
            } 
            else { 
                return aliasPath; 
            } 
        } 
        
        
        
        ///<summary>Returns configuration key value. If the configuration key value is not specified, it returns "".</summary>
        ///<param name="key">Configuration key name.</param>
        public static string GetConfigValue( string key ) { 
            if ( ConfigurationSettings.AppSettings[ key ] == null ) { 
                return ""; 
            } 
            else { 
                return ConfigurationSettings.AppSettings[ key ].Trim(); 
            } 
        } 
        
        
        
        ///<summary>Writes event to the event log.</summary>
        ///<param name="eventType">Type of the event. I = information, E = error, W = warning</param>
        ///<param name="source">Source of the event (Content, Administration, etc.)</param>
        ///<param name="eventCode">Event code (Security, Update, Delete, etc.)</param>
        ///<param name="nodeId">ID value of the document.</param>
        ///<param name="nodeNamePath">NamePath value of the document.</param>
        ///<param name="eventDescription">Detailed description of the event.</param>
        public static void LogEvent( string eventType, string source, string eventCode, int nodeId, string nodeNamePath, string eventDescription ) { 
            TreeProvider tree = Functions.GetTreeProvider(); 
            Kentico.CMS.EventLog.EventLogProvider log = new Kentico.CMS.EventLog.EventLogProvider( tree.Connection ); 
            log.LogEvent( eventType, DateAndTime.Now, source, eventCode, tree.UserID, HttpContext.Current.User.Identity.Name, nodeId, nodeNamePath, HttpContext.Current.Request.UserHostAddress, eventDescription ); 
        } 
        
        
        ///<summary>Gets result of Request.QueryString</summary>
        ///<param name="key">Name of the requested key</param>
        public static string RequestQueryString( string key ) { 
            return HttpContext.Current.Request.QueryString[ key ]; 
        } 
        
        
        ///<summary>Returns parentPath.</summary>
        ///<param name="path">Node path (could be alias-, name- or id-path)</param>
        public static string GetParentPath( string path ) { 
            if ( path == "/" ) { 
                return "/"; 
            } 
            else { 
                return path.Substring( 0, path.LastIndexOf( "/" ) ); 
            } 
        } 
        
        
        ///<summary>Recursive creates parent nodes of specific culture version, if they do not exist</summary>
        ///<param name="aliaspath">Node specified by this aliasPath is created when does not exist</param>
        public static TreeNode CreateNodePath( string aliaspath ) { 
            TreeProvider tree = Functions.GetTreeProvider(); 
            TreeNode node = tree.SelectSingleNode( aliaspath, TreePathTypeEnum.AliasPath ); 
            if ( node == null ) { 
                string parentAliasPath = GetParentPath( aliaspath ); 
                CreateNodePath( parentAliasPath ); 
                // copy default culture version of the specified node
                string defaultCulture = Functions.GetConfigValue( "CMSDefaultCultureCode" ); 
                string defaultCultureAliasPath = "/" + defaultCulture + Functions.RemoveCultureFromAliasPath( aliaspath ); 
                TreeNode resultNode = tree.CopyNode( defaultCultureAliasPath, parentAliasPath, TreePathTypeEnum.AliasPath, false ); 
                if ( ( !( ConfigurationSettings.AppSettings[ "CMSCopyAclOfTranslatedParentDocuments" ] == null ) ) && ConfigurationSettings.AppSettings[ "CMSCopyAclOfTranslatedParentDocuments" ].ToLower().Trim() == "true" ) { 
                    TreeNode defaultNode = tree.SelectSingleNode( defaultCultureAliasPath, Kentico.CMS.TreeEngine.TreePathTypeEnum.AliasPath ); 
                    resultNode.SetValue( "ACLID", defaultNode.GetValue( "ACLID" ) ); 
                    resultNode.Update(); 
                } 
                return resultNode; 
            } 
            else { 
                return node; 
            } 
        } 
        
    } 
    
    
} 
