Imports Kentico.CMS.CMSControls
Imports System.IO
Imports Kentico.DirectoryUtilities

Public Class FileManagerTreeData
    Inherits System.Web.UI.Page

    Private Const cImageBasePath As String = "../Design/Tree"
    Protected WithEvents ltlRender As System.Web.UI.WebControls.Literal
    Private Const cIconsBasePath As String = "../Design/FileIcons/"

#Region " Web Form Designer Generated Code "

    'This call is required by the Web Form Designer.
    <System.Diagnostics.DebuggerStepThrough()> Private Sub InitializeComponent()

    End Sub

    'NOTE: The following placeholder declaration is required by the Web Form Designer.
    'Do not delete or move it.
    Private designerPlaceholderDeclaration As System.Object

    Private Sub Page_Init(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Init
        'CODEGEN: This method call is required by the Web Form Designer
        'Do not modify it using the code editor.
        InitializeComponent()
    End Sub

#End Region

    Private Sub Page_Load(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load
        Dim action As String

        action = LCase(Trim(Request.QueryString("action") & ""))
        ltlRender.Text = "<script language=""javascript"">" & vbCrLf
        Select Case action
            Case "expandnode"                
                If Not Functions.IsAuthorizedPerResource("CMS.Files", "Read") Then
                    ShowErrorMessage(ResMan.GetString("AccessDenied.NotAllowedToRead"))
                Else
                    AddRenderScript(GetChildNodes(Request.QueryString("nodeid"), Request.QueryString("sample"), Request.QueryString("value")), Request.QueryString("nodeid"))
                    If Request.QueryString("selectID") & "" <> "" Then
                        AddSelectNodeScript(Request.QueryString("selectID"), False, True)
                    End If
                End If
            Case "delete"
                    If Not Functions.IsAuthorizedPerResource("CMS.Files", "Delete") Then
                        ShowErrorMessage(ResMan.GetString("AccessDenied.NotAllowedToDeleteFile"))
                    Else
                        AddSelectNodeScript(DeleteNode(Request.QueryString("idpath")), True, False)
                        AddReloadSelectedNodeScript()
                    End If
            Case "copy"
                    If Not (Functions.IsAuthorizedPerResource("CMS.Files", "Read") And Functions.IsAuthorizedPerResource("CMS.Files", "Create")) Then
                        ShowErrorMessage(ResMan.GetString("AccessDenied.NotAllowedToCopyFile"))
                    Else
                    If (Request.QueryString("idpath") & "").ToLower.StartsWith(Request.QueryString("sourceIDPath").ToLower) Then
                        ShowErrorMessage(ResMan.GetString("FileManagerTreeData.CannotCopyInside"))
                    Else
                        CopyNode(Request.QueryString("sourceIDPath"), Request.QueryString("idpath"))
                        AddSelectNodeScript(Request.QueryString("idpath"), True, False)
                        AddReloadSelectedNodeScript()
                    End If
                End If
            Case "move"
                    If Not Functions.IsAuthorizedPerResource("CMS.Files", "Modify") Then
                        ShowErrorMessage(ResMan.GetString("AccessDenied.NotAllowedToMove"))
                    Else
                    If (Request.QueryString("idpath") & "").ToLower.StartsWith(Request.QueryString("sourceIDPath").ToLower) Then
                        ShowErrorMessage(ResMan.GetString("FileManagerTreeData.CannotMoveInside"))
                    Else
                        MoveNode(Request.QueryString("sourceIDPath"), Request.QueryString("idpath"))
                        AddSelectNodeScript(Request.QueryString("idpath"), True, False)
                        AddRemoveNodeScript(Request.QueryString("sourceIDPath"))
                        AddReloadSelectedNodeScript()
                    End If
                End If
        End Select
        ltlRender.Text &= "</script>"
    End Sub


    '''<summary>Adds script that removes the given node from the displayed tree.</summary>
    '''<param name="nodeIDPath">IDPath of the node to be removed.</param>
    Public Sub AddRemoveNodeScript(ByVal nodeIDPath As String)
        ltlRender.Text &= " parent.frames['tree'].document.getElementById('nodeID_" & nodeIDPath & "').innerHTML = '';"
    End Sub


    '''<summary>Adds script that reloads the selected node.</summary>
    Public Sub AddReloadSelectedNodeScript()
        ltlRender.Text &= " parent.frames['tree'].ReloadSelectedNode();" & vbCrLf
    End Sub


    '''<summary>Adds script that selects given node.</summary>
    '''<param name="selectIDPath">IDPath of the node to be selected.</param>
    '''<param name="selectDesktop">Indicates if desktop should be updated.</param>
    '''<param name="selectMenu">Indicates if menu (header) selected item value should be updated.</param>
    Public Sub AddSelectNodeScript(ByVal selectIDPath As String, ByVal selectDesktop As Boolean, ByVal selectMenu As Boolean)
        ltlRender.Text &= " SelectNode('" & selectIDPath.Replace("'", "&apos;") & "'); " & vbCrLf & _
                         " function SelectNode(selectID) {" & vbCrLf & _
                         "  //try {" & vbCrLf & _
                         "  parent.frames['tree'].SelectNode(selectID);" & vbCrLf
        If selectDesktop Then
            ltlRender.Text &= "  parent.frames['header'].SelectNode(selectID);" & vbCrLf
        End If
        If selectMenu Then
            ltlRender.Text &= "  parent.frames['header'].document.getElementById('idpath').value = selectID;" & vbCrLf
        End If
        ltlRender.Text &= "  //} catch(e) { } " & vbCrLf & _
                          " } " & vbCrLf
    End Sub


    '''<summary>Adds content that will be rendered under given parent node.</summary>
    '''<param name="content">Content to be rendered.</param>
    '''<param name="targetNodeIDPath">Target node IDPath.</param>
    Public Sub AddRenderScript(ByVal content As String, ByVal targetNodeIDPath As String)
        Dim innerHTML As String
        innerHTML = Replace(content & "", "'", "\'")
        innerHTML = Replace(innerHTML, """", "\""")
        innerHTML = Replace(innerHTML, vbCrLf, " ")        

        ltlRender.Text &= " RenderData(); " & vbCrLf & _
                     " function RenderData() {" & vbCrLf & _
                     "  // try {" & vbCrLf & _
                     "  parent.frames['tree'].document.getElementById('sub_" & targetNodeIDPath & "').innerHTML = '" & innerHTML & "'; " & vbCrLf
        If innerHTML & "" = "" Then
            ltlRender.Text &= " parent.frames['tree'].document.getElementById('sub_" & targetNodeIDPath & "').style.display = 'none'; " & vbCrLf
        End If
        ltlRender.Text &= "  // } catch(e) { } " & vbCrLf & _
                     " } " & vbCrLf
    End Sub


    '''<summary>Returns child nodes at 2nd and lower level.</summary>
    '''<param name="NodeID">Parent node ID (IDPath).</param>
    '''<param name="Sample">Sample for displaying tree.</param>
    '''<param name="Value">Value of the parent node.</param>
    Function GetChildNodes(ByVal NodeID As String, ByVal Sample As String, ByVal Value As String) As String
        Dim nodes As New TreeNodes
        Dim i As Integer
        Dim items() As FileSystemInfo

        nodes.ImagePathBase = cImageBasePath
        items = GetFileSystemInfos(NodeID)
        If NodeID = "/" Then
            NodeID = ""
        End If
        'render folders
        For i = items.GetLowerBound(0) To items.GetUpperBound(0)
            If (items(i).Attributes() And FileAttributes.Directory) = FileAttributes.Directory Then
                'test if hidden folders should be displayed
                If Not (Not ConfigurationSettings.AppSettings("CMSShowHiddenFolders") Is Nothing AndAlso ConfigurationSettings.AppSettings("CMSShowHiddenFolders").ToLower = "false" AndAlso (items(i).Attributes() And FileAttributes.Hidden) = FileAttributes.Hidden) Then
                    nodes.NewNode(items(i).Name, Value, cIconsBasePath & "folder.gif", cIconsBasePath & "folder_open.gif", items(i).Name, "parent.frames['header'].SelectNode('" & NodeID & "/" & items(i).Name & "')", NodeID & "/" & items(i).Name, Sample, True)
                End If
            End If
        Next
        'render files
        For i = items.GetLowerBound(0) To items.GetUpperBound(0)
            If (items(i).Attributes() And FileAttributes.Directory) <> FileAttributes.Directory Then
                'test if hiddend files should be displayed
                If Not (Not ConfigurationSettings.AppSettings("CMSShowHiddenFiles") Is Nothing AndAlso ConfigurationSettings.AppSettings("CMSShowHiddenFiles").ToLower = "false" AndAlso (items(i).Attributes() And FileAttributes.Hidden) = FileAttributes.Hidden) Then
                    nodes.NewNode(items(i).Name, Value, cIconsBasePath & "file.gif", cIconsBasePath & "file_open.gif", items(i).Name, "parent.frames['header'].SelectNode('" & Server.UrlEncode(NodeID & "/" & items(i).Name.Replace("'", "&apos;")) & "')", NodeID & "/" & items(i).Name, Sample, False)
                End If
            End If
        Next
        Return nodes.NodesHTML
    End Function


    '''<summary>Deletes specified node and returns IDPath of its parent.</summary>
    '''<param name="IDPath">IDPath of the node to be deleted.</param>
    Function DeleteNode(ByVal IDPath As String) As String
        'delete the node
        Dim parentIDPath As String

        If IsFile(IDPath) Then
            'file
            File.Delete(GetDiskPath(IDPath))
        Else
            'folder
            Directory.Delete(GetDiskPath(IDPath), True)
        End If

        parentIDPath = Left(IDPath, Len(IDPath) - Len(Split(IDPath, "/")(Split(IDPath, "/").GetUpperBound(0))))
        If parentIDPath <> "/" And Right(parentIDPath, 1) = "/" Then
            parentIDPath = Left(parentIDPath, Len(parentIDPath) - 1)
        End If
        Return parentIDPath
    End Function


    '''<summary>Copies specified node.</summary>
    '''<param name="sourceID">Source IDPath.</param>
    '''<param name="targetIDPath">Target IDPath.</param>
    Sub CopyNode(ByVal sourceIDPath As String, ByVal targetIDPath As String)
        Dim safeTargetPath As String

        If IsFile(sourceIDPath) Then
            safeTargetPath = GetUniqueFilePath(GetDiskPath(targetIDPath) & "\" & Path.GetFileName(GetDiskPath(sourceIDPath)))
            File.Copy(GetDiskPath(sourceIDPath), safeTargetPath, True)
        Else
            safeTargetPath = GetUniqueFolderPath(GetDiskPath(targetIDPath) & "\" & Path.GetFileName(GetDiskPath(sourceIDPath)))
            CopyDirectory(GetDiskPath(sourceIDPath), safeTargetPath)
        End If
    End Sub


    '''<summary>Moves specified node.</summary>
    '''<param name="sourceID">Source IDPath.</param>
    '''<param name="targetIDPath">Target IDPath.</param>
    Sub MoveNode(ByVal sourceIDPath As String, ByVal targetIDPath As String)
        Dim safeTargetPath As String        
        
        If IsFile(sourceIDPath) Then
            safeTargetPath = GetUniqueFilePath(GetDiskPath(targetIDPath) & "\" & Path.GetFileName(GetDiskPath(sourceIDPath)))
            File.Move(GetDiskPath(sourceIDPath), safeTargetPath)
        Else
            safeTargetPath = GetUniqueFolderPath(GetDiskPath(targetIDPath) & "\" & Path.GetFileName(GetDiskPath(sourceIDPath)))
            DirectoryHelper.MoveDirectory(GetDiskPath(sourceIDPath), safeTargetPath)
        End If
    End Sub


    '''<summary>Checks if provided file already exists and if so, it adds a number at the end of its name.</summary>
    Protected Function GetUniqueFilePath(ByVal path As String) As String
        Dim i As Integer
        Dim newPath As String
        Dim extension As String
        Dim trimExtension As String

        newPath = path
        While File.Exists(newPath)
            If InStr(newPath, ".") > 0 Then
                trimExtension = newPath.Substring(0, newPath.LastIndexOf("."))
                extension = newPath.Substring(newPath.LastIndexOf("."))
                newPath = trimExtension & " (" & i & ")" & extension
            Else
                newPath = path & " (" & i & ")"
            End If
            i += 1
        End While
        Return newPath
    End Function


    '''<summary>Checks if provided folder already exists and if so, it adds a number at the end of its name.</summary>
    Protected Function GetUniqueFolderPath(ByVal path As String) As String
        Dim i As Integer
        Dim newPath As String

        newPath = path
        While Directory.Exists(newPath)
            newPath = path & " (" & i & ")"
            i += 1
        End While
        Return newPath
    End Function


    '''<summary>Returns information about files and folders.</summary>
    '''<param name="relativePath">Relative path to the parent folder.</param>
    Protected Function GetFileSystemInfos(ByVal relativePath As String) As FileSystemInfo()
        Dim folderPath As String
        Dim di As DirectoryInfo

        folderPath = Functions.GetFilesPath & Replace(relativePath & "", "/", "\")
        di = New DirectoryInfo(folderPath)
        Return di.GetFileSystemInfos
    End Function


    '''<summary>Returns true in case the provided item is a file.</summary>
    '''<param name="IDPath">Relative path to the item (file or folder).</param>
    Protected Function IsFile(ByVal IDPath As String) As Boolean
        Dim fileInf As FileInfo
        Dim diskPath As String

        diskPath = GetDiskPath(IDPath)
        fileInf = New FileInfo(diskPath)
        If (fileInf.Attributes And FileAttributes.Directory) <> FileAttributes.Directory Then
            'file
            Return True
        Else
            'folder
            Return False
        End If
    End Function


    '''<summary>Returns disk path for the given relative path.</summary>
    '''<param name="IDPath">Relative path to the file or folder.</param>
    Protected Function GetDiskPath(ByVal IDPath As String) As String
        Return Functions.GetFilesPath & Replace(IDPath, "/", "\")
    End Function


    '''<summary>Copies folder including its subfolders and all files.</summary>
    '''<param name="sourceDirectory">Physical path of the source folder.</param>
    '''<param name="targetDirectory">Physical path of the target folder.</param>
    Public Sub CopyDirectory(ByVal sourceDirectory As String, ByVal targetDirectory As String)
        DirectoryHelper.CopyDirectory(sourceDirectory, targetDirectory)
    End Sub


    '''<summary>Displays an error message.</summary>
    '''<param name="message">Error message.</param>
    Public Sub ShowErrorMessage(ByVal message As String)
        ltlRender.Text &= " alert('" & Replace(message & "", "'", "\'") & "');"
    End Sub


End Class
