ALTER TABLE [CMS_Resource] ADD
[ShowInToolsMenu] [bit] NULL,
[ResourceURL] [nvarchar] (1000) COLLATE SQL_Latin1_General_CP1_CI_AS NULL
GO

ALTER TABLE [CONTENT_MenuItem] ADD
[MenuItemPageContent] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NULL
GO

ALTER PROCEDURE Proc_CMS_Resource_Insert @ResourceID int, @ResourceName nvarchar(100), @ResourceDisplayName nvarchar(100), @ShowInToolsMenu bit, @ResourceURL nvarchar(1000)

AS

SET XACT_ABORT ON
begin tran

INSERT INTO cms_resource (ResourceName, ResourceDisplayName, ShowInToolsMenu, ResourceURL)
VALUES (@ResourceName, @ResourceDisplayName, @ShowInToolsMenu, @ResourceURL)

SELECT @@identity as ResourceID

commit tran

GO

ALTER PROCEDURE Proc_CMS_Resource_Update @ResourceID int, @ResourceName nvarchar(100), @ResourceDisplayName nvarchar(100), @ShowInToolsMenu bit, @ResourceURL nvarchar(1000)

AS

UPDATE cms_resource
SET resourcename = @resourcename,
resourcedisplayname = @resourcedisplayname,
showintoolsmenu	= @showintoolsmenu,
resourceurl = @resourceurl
WHERE resourceid = @resourceid

GO

CREATE TABLE [Newsletter_Newsletter]
(
[NewsletterID] [int] NOT NULL IDENTITY(1, 1),
[NewsletterName] [nvarchar] (200) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[NewsletterConfirmationText] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL CONSTRAINT [DF__Newslette__Newsl__51300E55] DEFAULT (''),
[NewsletterUnsubscriptionText] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL CONSTRAINT [DF__Newslette__Newsl__5224328E] DEFAULT ('')
)
GO

CREATE TABLE [Newsletter_NewsletterContainer]
(
[NewsletterContainerID] [int] NOT NULL IDENTITY(1, 1),
[NewsletterContainerName] [nvarchar] (100) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL CONSTRAINT [DEFAULT_Newsletter_NewsletterContainer_NewsletterContainerName] DEFAULT ('')
)
GO

CREATE TABLE [Newsletter_NewsletterIssue]
(
[NewsletterIssueID] [int] NOT NULL IDENTITY(1, 1),
[NewsletterSubject] [nvarchar] (400) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL CONSTRAINT [DF__Newslette__Newsl__2180FB33] DEFAULT (''),
[NewsletterBody] [ntext] COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL CONSTRAINT [DF__Newslette__Newsl__22751F6C] DEFAULT (''),
[NewsletterReleaseDate] [datetime] NOT NULL CONSTRAINT [DF__Newslette__Newsl__236943A5] DEFAULT ('12:00:00'),
[NewsletterSentEmails] [int] NULL,
[NewsletterUnsubscriptions] [int] NULL
)
GO
CREATE TABLE [Newsletter_Subscriber]
(
[SubscriberID] [int] NOT NULL IDENTITY(1, 1),
[SubscriberEmail] [nvarchar] (400) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL CONSTRAINT [DF__Newslette__Subsc__4F47C5E3] DEFAULT (''),
[SubscriberFirstName] [nvarchar] (200) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[SubscriberLastName] [nvarchar] (200) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
[SubscriberFullName] [nvarchar] (450) COLLATE SQL_Latin1_General_CP1_CI_AS NULL
)
GO

CREATE TABLE [Newsletter_Subscriptions]
(
[SubscriberID] [int] NOT NULL,
[NewsletterID] [int] NOT NULL
)
GO

ALTER TABLE [Newsletter_Newsletter] ADD CONSTRAINT [PK_Newsletter_Newsletter] PRIMARY KEY CLUSTERED  ([NewsletterID])
GO

ALTER TABLE [Newsletter_NewsletterContainer] ADD CONSTRAINT [PK_Newsletter_NewsletterContainer] PRIMARY KEY CLUSTERED  ([NewsletterContainerID])
GO

ALTER TABLE [Newsletter_NewsletterIssue] ADD CONSTRAINT [PK_Newsletter_NewsletterIssue] PRIMARY KEY CLUSTERED  ([NewsletterIssueID])
GO

ALTER TABLE [Newsletter_Subscriber] ADD CONSTRAINT [PK_Newsletter_Subscriber] PRIMARY KEY CLUSTERED  ([SubscriberID])
GO

ALTER TABLE [Newsletter_Subscriptions] ADD CONSTRAINT [PK_Newsletter_Subscriptions] PRIMARY KEY CLUSTERED  ([SubscriberID], [NewsletterID])
GO

ALTER TABLE [Newsletter_Subscriptions] ADD
CONSTRAINT [FK_Newsletter_Subscriptions_Newsletter_Subscriber] FOREIGN KEY ([SubscriberID]) REFERENCES [Newsletter_Subscriber] ([SubscriberID]),
CONSTRAINT [FK_Newsletter_Subscriptions_Newsletter_Newsletter] FOREIGN KEY ([NewsletterID]) REFERENCES [Newsletter_Newsletter] ([NewsletterID])
GO

declare @newsletterclassid int
INSERT [CMS_Class] ([ClassDisplayName], [ClassName], [IsCoupledClass], [ApplicationID], [UseVersioning], [WorkflowID]) VALUES ('Newsletter', 'CMS.Newsletter', 1, 1, 0, NULL)
set @newsletterclassid=@@identity

declare @containerclassid int
INSERT [CMS_Class] ([ClassDisplayName], [ClassName], [IsCoupledClass], [ApplicationID], [UseVersioning], [WorkflowID]) VALUES ('Newsletter Container', 'CMS.NewsletterContainer', 1, 1, 0, NULL)
set @containerclassid=@@identity

declare @issueclassid int
INSERT [CMS_Class] ([ClassDisplayName], [ClassName], [IsCoupledClass], [ApplicationID], [UseVersioning], [WorkflowID]) VALUES ('Newsletter Issue', 'CMS.NewsletterIssue', 1, 1, 0, NULL)
set @issueclassid=@@identity

declare @parentid int
set @parentid=(SELECT [ClassID] FROM [CMS_Class] WHERE ClassName='CMS.Root')
if @parentid<>0 INSERT [CMS_AllowedChildClasses] ([ParentClassID], [ChildClassID]) VALUES (@parentid, @containerclassid)

set @parentid=(SELECT [ClassID] FROM [CMS_Class] WHERE ClassName='CMS.Culture')
if @parentid<>0 INSERT [CMS_AllowedChildClasses] ([ParentClassID], [ChildClassID]) VALUES (@parentid, @containerclassid)
INSERT [CMS_AllowedChildClasses] ([ParentClassID], [ChildClassID]) VALUES (@containerclassid, @newsletterclassid)
INSERT [CMS_AllowedChildClasses] ([ParentClassID], [ChildClassID]) VALUES (@newsletterclassid, @issueclassid)


INSERT [CMS_Permission] ([PermissionDisplayName], [PermissionName], [ClassID], [ResourceID]) VALUES ('Create', 'Create', @newsletterclassid, NULL)
INSERT [CMS_Permission] ([PermissionDisplayName], [PermissionName], [ClassID], [ResourceID]) VALUES ('Modify', 'Modify', @newsletterclassid, NULL)
INSERT [CMS_Permission] ([PermissionDisplayName], [PermissionName], [ClassID], [ResourceID]) VALUES ('Delete', 'Delete', @newsletterclassid, NULL)
INSERT [CMS_Permission] ([PermissionDisplayName], [PermissionName], [ClassID], [ResourceID]) VALUES ('Read', 'Read', @newsletterclassid, NULL)
INSERT [CMS_Permission] ([PermissionDisplayName], [PermissionName], [ClassID], [ResourceID]) VALUES ('Destroy', 'Destroy', @newsletterclassid, NULL)
INSERT [CMS_Permission] ([PermissionDisplayName], [PermissionName], [ClassID], [ResourceID]) VALUES ('Modify Permissions', 'ModifyPermissions', @newsletterclassid, NULL)

INSERT [CMS_Permission] ([PermissionDisplayName], [PermissionName], [ClassID], [ResourceID]) VALUES ('Create', 'Create', @containerclassid, NULL)
INSERT [CMS_Permission] ([PermissionDisplayName], [PermissionName], [ClassID], [ResourceID]) VALUES ('Modify', 'Modify', @containerclassid, NULL)
INSERT [CMS_Permission] ([PermissionDisplayName], [PermissionName], [ClassID], [ResourceID]) VALUES ('Delete', 'Delete', @containerclassid, NULL)
INSERT [CMS_Permission] ([PermissionDisplayName], [PermissionName], [ClassID], [ResourceID]) VALUES ('Read', 'Read', @containerclassid, NULL)
INSERT [CMS_Permission] ([PermissionDisplayName], [PermissionName], [ClassID], [ResourceID]) VALUES ('Destroy', 'Destroy', @containerclassid, NULL)
INSERT [CMS_Permission] ([PermissionDisplayName], [PermissionName], [ClassID], [ResourceID]) VALUES ('Modify Permissions', 'ModifyPermissions', @containerclassid, NULL)

INSERT [CMS_Permission] ([PermissionDisplayName], [PermissionName], [ClassID], [ResourceID]) VALUES ('Create', 'Create', @issueclassid, NULL)
INSERT [CMS_Permission] ([PermissionDisplayName], [PermissionName], [ClassID], [ResourceID]) VALUES ('Modify', 'Modify', @issueclassid, NULL)
INSERT [CMS_Permission] ([PermissionDisplayName], [PermissionName], [ClassID], [ResourceID]) VALUES ('Delete', 'Delete', @issueclassid, NULL)
INSERT [CMS_Permission] ([PermissionDisplayName], [PermissionName], [ClassID], [ResourceID]) VALUES ('Read', 'Read', @issueclassid, NULL)
INSERT [CMS_Permission] ([PermissionDisplayName], [PermissionName], [ClassID], [ResourceID]) VALUES ('Destroy', 'Destroy', @issueclassid, NULL)
INSERT [CMS_Permission] ([PermissionDisplayName], [PermissionName], [ClassID], [ResourceID]) VALUES ('Modify Permissions', 'ModifyPermissions', @issueclassid, NULL)


declare @adminsid int
set @adminsid=(SELECT [RoleID] FROM [CMS_Role] WHERE Rolename='CMS.Administrators')

declare @developersid int
set @developersid=(SELECT [RoleID] FROM [CMS_Role] WHERE Rolename='CMS.Developers')


declare @resourceid int
INSERT [CMS_Resource] ([ResourceDisplayName], [ResourceName], [ShowInToolsMenu], [ResourceURL]) VALUES ('CMS Tools', 'CMS.Tools', 0, NULL)
set @resourceid=@@identity


declare @permissionid int
INSERT [CMS_Permission] ([PermissionDisplayName], [PermissionName], [ClassID], [ResourceID]) VALUES ('Create', 'Create', NULL, @resourceid)
set @permissionid=@@identity
if @adminsid<>0 INSERT [CMS_RolePermission] ([RoleID], [PermissionID]) VALUES (@adminsid, @permissionid)
INSERT [CMS_Permission] ([PermissionDisplayName], [PermissionName], [ClassID], [ResourceID]) VALUES ('Modify', 'Modify', NULL, @resourceid)
set @permissionid=@@identity
if @adminsid<>0 INSERT [CMS_RolePermission] ([RoleID], [PermissionID]) VALUES (@adminsid, @permissionid)
INSERT [CMS_Permission] ([PermissionDisplayName], [PermissionName], [ClassID], [ResourceID]) VALUES ('Delete', 'Delete', NULL, @resourceid)
set @permissionid=@@identity
if @adminsid<>0 INSERT [CMS_RolePermission] ([RoleID], [PermissionID]) VALUES (@adminsid, @permissionid)
INSERT [CMS_Permission] ([PermissionDisplayName], [PermissionName], [ClassID], [ResourceID]) VALUES ('Read', 'Read', NULL, @resourceid)
set @permissionid=@@identity
if @adminsid<>0 INSERT [CMS_RolePermission] ([RoleID], [PermissionID]) VALUES (@adminsid, @permissionid)
if @developersid<>0 INSERT [CMS_RolePermission] ([RoleID], [PermissionID]) VALUES (@developersid, @permissionid)


INSERT [CMS_Resource] ([ResourceDisplayName], [ResourceName], [ShowInToolsMenu], [ResourceURL]) VALUES ('CMS Newsletter', 'CMS.Newsletter', 1,'Newsletter/subscribers/SubscriberList.aspx')
set @resourceid=@@identity


INSERT [CMS_Permission] ([PermissionDisplayName], [PermissionName], [ClassID], [ResourceID]) VALUES ('Create', 'Create', NULL, @resourceid)
set @permissionid=@@identity
if @adminsid<>0 INSERT [CMS_RolePermission] ([RoleID], [PermissionID]) VALUES (@adminsid, @permissionid)
INSERT [CMS_Permission] ([PermissionDisplayName], [PermissionName], [ClassID], [ResourceID]) VALUES ('Modify', 'Modify', NULL, @resourceid)
set @permissionid=@@identity
if @adminsid<>0 INSERT [CMS_RolePermission] ([RoleID], [PermissionID]) VALUES (@adminsid, @permissionid)
INSERT [CMS_Permission] ([PermissionDisplayName], [PermissionName], [ClassID], [ResourceID]) VALUES ('Delete', 'Delete', NULL, @resourceid)
set @permissionid=@@identity
if @adminsid<>0 INSERT [CMS_RolePermission] ([RoleID], [PermissionID]) VALUES (@adminsid, @permissionid)
INSERT [CMS_Permission] ([PermissionDisplayName], [PermissionName], [ClassID], [ResourceID]) VALUES ('Read', 'Read', NULL, @resourceid)
set @permissionid=@@identity
if @adminsid<>0 INSERT [CMS_RolePermission] ([RoleID], [PermissionID]) VALUES (@adminsid, @permissionid)
if @developersid<>0 INSERT [CMS_RolePermission] ([RoleID], [PermissionID]) VALUES (@developersid, @permissionid)


INSERT [CMS_Resource] ([ResourceDisplayName], [ResourceName], [ShowInToolsMenu], [ResourceURL]) VALUES ('CMS Shopping Cart', 'CMS.ShoppingCart', 0,'ShoppingCart/default.aspx')
set @resourceid=@@identity


INSERT [CMS_Permission] ([PermissionDisplayName], [PermissionName], [ClassID], [ResourceID]) VALUES ('Manage Store', 'Manage', NULL, @resourceid)
set @permissionid=@@identity
if @adminsid<>0 INSERT [CMS_RolePermission] ([RoleID], [PermissionID]) VALUES (@adminsid, @permissionid)

GO


ALTER  PROCEDURE Proc_CMS_Tree_Delete @ID int
AS

SET XACT_ABORT ON

begin tran


DELETE FROM cms_WorkflowHistory WHERE VersionHistoryID IN (select versionhistoryid from cms_VersionHistory where nodeid = @ID)

UPDATE cms_tree SET checkedoutversionhistoryid = NULL WHERE checkedoutversionhistoryid IN (select versionhistoryid from cms_VersionHistory where nodeid = @ID)

UPDATE cms_tree SET publishedversionhistoryid = NULL WHERE publishedversionhistoryid IN (select versionhistoryid from cms_VersionHistory where nodeid = @ID)

UPDATE cms_tree SET ACLID = NULL where ACLID IN (SELECT aclid FROM cms_acl WHERE ownernodeid = @ID)

DELETE FROM CMS_ACLItem WHERE ACLID IN (select aclid from cms_acl where ownernodeid = @ID)

DELETE FROM CMS_ACL WHERE ownernodeid = @ID

DELETE FROM cms_relationship WHERE LeftNodeID = @ID OR RightNodeID = @ID

DELETE FROM cms_tree WHERE nodeid = @ID

commit tran

GO


ALTER  PROCEDURE Proc_CMS_Tree_MoveNodes @SourceIDPath varchar(450), @TargetIDPath varchar(450), @SourceAliasPath nvarchar(450), @TargetAliasPath nvarchar(450), @SourceNamePath nvarchar(450), @TargetNamePath nvarchar(450), @LevelDiff int, @LeftTrimIDPath int, @LeftTrimAliasPath int, @LeftTrimNamePath int
AS

SET XACT_ABORT ON

begin tran



UPDATE cms_tree
set parentNodeID = (select nodeID from cms_tree where idpath = @targetIDPath)
WHERE IDPath = @SourceIDPath

UPDATE cms_tree
SET
idpath = @TargetIDPath + right(idpath, len(idpath)  - @LeftTrimIDPath) ,
aliaspath = @TargetAliasPath + right(aliaspath, len(aliaspath) - @LeftTrimAliasPath)  ,
namepath = @TargetNamePath + right(namepath, len(namepath) - @LeftTrimNamePath) ,
nodelevel = nodelevel + @LevelDiff
WHERE
left(idpath, len(@SourceIDPath)+1) = @SourceIDPath + '/'
OR
idpath = @SourceIDPath

commit tran


GO

