using Kentico.CMS.TreeEngine; 
using Kentico.CMS.DataEngine; 
using System.IO; 
using System.ComponentModel; 
using System.Configuration; 
using System.Globalization; 

///<summary>Shared class providing common functions for all pages.</summary>
using Microsoft.VisualBasic;
using System;
using System.Collections;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.UI;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;
namespace WebProjectCS {
    public class Functions  { 
        
        ///<summary>Constructor.</summary>
        static Functions() { 
        } 
        
        
        ///<summary>Returns connection string used throughout the application.</summary>
        public static string GetConnectionString() { 
            return ConfigurationSettings.AppSettings[ "CMSConnectionString" ]; 
        } 
        
        
        
        ///<summary>Creates and returns a new, initialized instance of TreeProvider with current user set.</summary>
        public static TreeProvider GetTreeProvider() { 
            TreeProvider tree = new TreeProvider(); 
            
            tree.Connection.ConnectionString = GetConnectionString(); 
            tree.UserID = GetUserID(); 
            return tree; 
        } 
        
        
        
        ///<summary>Returns User ID of the current user.</summary>
        public static int GetUserID() { 
            if ( System.Web.HttpContext.Current.Session[ "CMSUserID" ] == null & HttpContext.Current.User.Identity.IsAuthenticated ) { 
                Functions.SetCurrentUserID( System.Web.HttpContext.Current.User.Identity.Name ); 
            } 
            if ( System.Web.HttpContext.Current.Session[ "CMSUserID" ] == null ) { 
                System.Web.HttpContext.Current.Session[ "CMSUserID" ] = 0; 
            } 
            return System.Convert.ToInt32( System.Web.HttpContext.Current.Session[ "CMSUserID" ] ); 
        } 
        
        
        
        ///<summary>Returns physical path to the files (documents) folder.</summary>
        public static string GetFilesPath() { 
            return HttpContext.Current.Server.MapPath( ConfigurationSettings.AppSettings[ "CMSFilesFolder" ] ); 
        } 
        
        
        
        ///<summary>Returns true if multilingual support is switched on.</summary>
        public static bool UseMultilingualSupport() { 
            if ( Strings.Trim( Strings.LCase( ConfigurationSettings.AppSettings[ "CMSUseMultilingualSupport" ] + "" ) ) == "true" ) { 
                return true; 
            } 
            else { 
                return false; 
            } 
        } 
        
        
        
        ///<summary>Removes culture from alias path if you're using multilingual support with hidden culture.</summary>
        public static string RemoveCultureFromAliasPath( object aliasPath ) { 
			string alPath;
			if (aliasPath != null)
			{
				alPath = aliasPath.ToString();
			}
			else
			{
				alPath = "/";
			}
            if ( UseMultilingualSupport() ) { 
                return alPath.Substring( alPath.Split( '/' )[ 1 ].Length + 1 ); 
            } 
            else { 
                return alPath; 
            } 
        } 
        
        
        
        ///<summary>Returns Web application virtual path.</summary>
        ///<remarks>It uses the CMSWebApplicationVirtualPath configuration parameter. If it's not used, "~/" is returned.</remarks>
        public static string GetWebApplicationVirtualPath() { 
            if ( ConfigurationSettings.AppSettings[ "CMSWebApplicationVirtualPath" ] == null || ConfigurationSettings.AppSettings[ "CMSWebApplicationVirtualPath" ] + "" == "" ) { 
                return "~/."; 
            } 
            else { 
                return ConfigurationSettings.AppSettings[ "CMSWebApplicationVirtualPath" ]; 
            } 
        } 
        
        
        
        ///<summary>Returns base disk path of the attachments folder.</summary>
        public static string GetAttachmentBaseDiskPath() { 
            if ( !( ConfigurationSettings.AppSettings[ "CMSAttachmentsFolder" ] == null ) && ConfigurationSettings.AppSettings[ "CMSAttachmentsFolder" ]+ "" != "" ) { 
                // attachments folder is specified
                if ( ConfigurationSettings.AppSettings[ "CMSAttachmentsFolder" ].StartsWith( "/" ) ) { 
                    // it's a virtual folder
                    return HttpContext.Current.Server.MapPath( ConfigurationSettings.AppSettings[ "CMSAttachmentsFolder" ] ); 
                } 
                else { 
                    // it's a physical path
                    return ConfigurationSettings.AppSettings[ "CMSAttachmentsFolder" ]; 
                } 
            } 
            else { 
                // attachments folder is not specified - use web path instead
                if ( GetWebApplicationVirtualPath()+ "" != "" ) { 
                    return HttpContext.Current.Server.MapPath( GetWebApplicationVirtualPath() ); 
                } 
                else { 
                    return HttpContext.Current.Server.MapPath( "~/." ); 
                } 
            } 
        } 
        
        
        
        ///<summary>Returns folder path of the file specified by alias path.</summary>
        ///<param name="aliasPath">Alias Path of the node.</param>
        public static string GetFileFolderPath( string aliasPath ) { 
            string result = ""; 
            
            aliasPath = Functions.RemoveCultureFromAliasPath( aliasPath ); 
            if ( aliasPath.ToLower().StartsWith( "/files" ) ) { 
                // this is a files folder
                if ( ( !( ConfigurationSettings.AppSettings[ "CMSFilesFolder" ] == null ) ) && ( ConfigurationSettings.AppSettings[ "CMSFilesFolder" ]+ "" != "" ) ) { 
                    result = System.Web.HttpContext.Current.Server.MapPath( ConfigurationSettings.AppSettings[ "CMSFilesFolder" ] ); 
                } 
                else { 
                    result = System.Web.HttpContext.Current.Server.MapPath( "~/files" ); 
                } 
                // replace "/files"
                aliasPath = aliasPath.Substring( "/files".Length ); 
            } 
            else { 
                result = GetAttachmentBaseDiskPath(); 
            } 
            if ( result.EndsWith( @"\" ) ) { 
                result = result.Substring( 0, result.Length - 1 ); 
            } 
            // remove last part of the alias path (the file name)
            string[] pathSplit = aliasPath.Split( '/' ); 
            aliasPath = aliasPath.Substring( 0, aliasPath.Length - pathSplit[ pathSplit.Length - 1 ].Length ); 
            if ( aliasPath.EndsWith( "/" ) ) { 
                aliasPath = aliasPath.Substring( 0, aliasPath.Length - 1 ); 
            } 
            // add alias path
            result += aliasPath.Replace( '/', '\\' ); 
            return result; 
        } 
        
        
        
        ///<summary>Returns true if the current user is authorized to access the given resource (module) with required permission.</summary>
        ///<param name="resourceName">Resource name.</param>
        ///<param name="permissionName">Permission name.</param>
        public static bool IsAuthorizedPerResource( string resourceName, string permissionName ) { 
            TreeSecurityProvider treeSec = new TreeSecurityProvider( Functions.GetTreeProvider() ); 
            return treeSec.IsAuthorizedPerResource( resourceName, permissionName ); 
        } 
        
        
        
        ///<summary>Returns true if the current user is authorized to access the given node (document) with required permission.</summary>
        ///<param name="path">Node path.</param>
        ///<param name="pathType">Type of the provided path.</param>
        ///<param name="permission">Required permission.</param>
        ///<remarks>This method checks not only the permissions for the given node. Rather, it also checks if the user was granted with specified permission for the CMS.Content resource.</remarks>
        public static bool IsAuthorizedPerNode( string path, TreePathTypeEnum pathType, NodePermissionsEnum permission ) { 
            TreeSecurityProvider treeSec = new TreeSecurityProvider( Functions.GetTreeProvider() ); 
            return Functions.IsAuthorizedPerResource( "CMS.Content", treeSec.GetPermissionName( permission ) ) | treeSec.IsAuthorizedPerNode( path, pathType, permission ); 
        } 
        
        
        
        ///<summary>Returns true if the current user is authorized to access the given class (document type) with required permission.</summary>
        ///<param name="className">Class name in format application.class.</param>    
        ///<param name="permissionName">Name of the required permission..</param>    
        public static bool IsAuthorizedPerClass( string className, string permissionName ) { 
            TreeSecurityProvider treeSec = new TreeSecurityProvider( Functions.GetTreeProvider() ); 
            return treeSec.IsAuthorizedPerClass( className, permissionName ); 
        } 
        
        
        
        ///<summary>Sets current user's ID into a session variable for further use.</summary>
        ///<param name="userName">User name.</param>
        public static void SetCurrentUserID( string userName ) { 
            GeneralConnection cn = new GeneralConnection( Functions.GetConnectionString() ); 
            object[,] paramsIdent = new object[ 1, 3 ]; 
            DataSet ds = null; 
            
            paramsIdent[ 0, 0 ] = "@UserName"; 
            paramsIdent[ 0, 1 ] = userName; 
            ds = cn.ExecuteQuery( "CMS.User.selectbyusername", paramsIdent ); 
            if ( ds.Tables[ 0 ].Rows.Count > 0 ) { 
                System.Web.HttpContext.Current.Session[ "CMSUserID" ] = ds.Tables[ 0 ].Rows[ 0 ][ "UserID" ]; 
            } 
            else { 
                System.Web.HttpContext.Current.Session[ "CMSUserID" ] = 0; 
            } 
        } 
        
        
        
        ///<summary>Redirects user to the "Access Denied" page.</summary>
        ///<param name="resourceName">Name of the resource that cannot be accessed.</param>
        ///<param name="permissionName">Name of the permission that is not allowed.</param>
        public static void RedirectToAccessDenied( string resourceName, string permissionName ) { 
            System.Web.HttpContext.Current.Response.Redirect( "~/cmsdesk/accessdenied.aspx?resource=" + resourceName + "&permission=" + permissionName ); 
        } 
        
        
        
        ///<summary>Returns preferred UI culture of the current user.</summary>
        public static CultureInfo GetPreferredUICulture() { 
            if ( Functions.GetUserID() == 0 ) { 
                return System.Threading.Thread.CurrentThread.CurrentCulture; 
            } 
            if ( HttpContext.Current.Session[ "CMSUserPreferredUICulture" ] == null ) { 
                // get preferred language
                DataClass userObj = null; 
                TreeProvider tree = Functions.GetTreeProvider(); 
                
                userObj = new DataClass( "cms.user", Functions.GetUserID(), tree.Connection ); 
                if ( Strings.Trim( System.Convert.ToString( userObj.GetValue( "PreferredUICultureCode" ) ) + "" )+ "" != "" ) { 
                    HttpContext.Current.Session[ "CMSUserPreferredUICulture" ] = new CultureInfo( Strings.Trim( System.Convert.ToString( userObj.GetValue( "PreferredUICultureCode" ) ) + "" ) ); 
                } 
                else { 
                    HttpContext.Current.Session[ "CMSUserPreferredUICulture" ] = System.Threading.Thread.CurrentThread.CurrentCulture; 
                } 
            } 
            System.Threading.Thread.CurrentThread.CurrentCulture = ( ( CultureInfo )( HttpContext.Current.Session[ "CMSUserPreferredUICulture" ] ) ); 
            System.Threading.Thread.CurrentThread.CurrentUICulture = ( ( CultureInfo )( HttpContext.Current.Session[ "CMSUserPreferredUICulture" ] ) ); 
            return ( ( CultureInfo )( HttpContext.Current.Session[ "CMSUserPreferredUICulture" ] ) ); 
        } 
        
        
        
        ///<summary>Returns current alias path based on base alias path setting and "aliaspath" querystring parameter.</summary>
        public static string GetAliasPath() { 
            return ConfigurationSettings.AppSettings[ "CMSWebSiteBaseAliasPath" ] + HttpContext.Current.Request.QueryString[ "aliaspath" ]; 
        } 
        
        
        
        ///<summary>Returns page title tag (applicable only on page templates).</summary>
        ///<param name="defaultAliasPath">Default alias path that is used when no aliaspath parameter is provided in the querystring.</param>
        public static string GetPageTitleTag( string defaultAliasPath ) { 
            string title = ConfigurationSettings.AppSettings[ "CMSPageTitlePrefix" ]; 
            DataRow dr = null; 
            
            if ( HttpContext.Current.Request.QueryString[ "aliaspath" ] == null || HttpContext.Current.Request.QueryString[ "aliaspath" ] + "" == "" ) { 
                // use provided alias path only if no alias path is passed in the querystring
                dr = GetPageInfoDR( defaultAliasPath ); 
            } 
            else { 
                // use alias path from the querystring
                dr = GetPageInfoDR( Functions.GetAliasPath() ); 
            } 
            if ( !( dr == null ) && !( dr[ "MenuItemPageTitle" ] == DBNull.Value ) ) { 
                title += System.Convert.ToString( dr[ "MenuItemPageTitle" ] ); 
            } 
            else { 
                title += ""; 
            } 
            return "<title>" + HttpContext.Current.Server.HtmlEncode( title ) + "</title>"; 
        } 
        
        
        
        ///<summary>Returns page meta tag "description" (applicable only on page templates).</summary>
        ///<param name="defaultAliasPath">Default alias path that is used when no aliaspath parameter is provided in the querystring.</param>
        public static string GetPageMetaDescriptionTag( string defaultAliasPath ) { 
            string description = null; 
            DataRow dr = null; 
            
            if ( HttpContext.Current.Request.QueryString[ "aliaspath" ] == null || HttpContext.Current.Request.QueryString[ "aliaspath" ] + "" == "" ) { 
                // use provided alias path only if no alias path is passed in the querystring
                dr = GetPageInfoDR( defaultAliasPath ); 
            } 
            else { 
                // use alias path from the querystring
                dr = GetPageInfoDR( Functions.GetAliasPath() ); 
            } 
            if ( !( dr == null ) && !( dr[ "MenuItemPageDescription" ] == DBNull.Value ) ) { 
                description = System.Convert.ToString( dr[ "MenuItemPageDescription" ] ); 
            } 
            else { 
                description = ""; 
            } 
            return @"<meta name=""description"" content=""" + HttpContext.Current.Server.HtmlEncode( description ) + @"""/>"; 
        } 
        
        
        
        ///<summary>Returns page meta tag "keywords" (applicable only on page templates).</summary>
        ///<param name="defaultAliasPath">Default alias path that is used when no aliaspath parameter is provided in the querystring.</param>    
        public static string GetPageMetaKeyWordsTag( string defaultAliasPath ) { 
            string keywords = null; 
            DataRow dr = null; 
            
            if ( HttpContext.Current.Request.QueryString[ "aliaspath" ] == null || HttpContext.Current.Request.QueryString[ "aliaspath" ] + "" == "" ) { 
                // use provided alias path only if no alias path is passed in the querystring
                dr = GetPageInfoDR( defaultAliasPath ); 
            } 
            else { 
                // use alias path from the querystring
                dr = GetPageInfoDR( Functions.GetAliasPath() ); 
            } 
            if ( !( dr == null ) && !( dr[ "MenuItemPageKeyWords" ] == DBNull.Value ) ) { 
                keywords = System.Convert.ToString( dr[ "MenuItemPageKeyWords" ] ); 
            } 
            else { 
                keywords = ""; 
            } 
            return @"<meta name=""keywords"" content=""" + HttpContext.Current.Server.HtmlEncode( keywords ) + @"""/>"; 
        } 
        
        
        
        ///<summary>Returns CSS file link tag.</summary>
        ///<param name="defaultAliasPath">Default alias path that is used when no aliaspath parameter is provided in the querystring.</param>        
        public static string GetCSSFileLink( string defaultAliasPath ) { 
            DataRow dr = null; 
            string result = null; 
            string appPath = null; 
            string cssfile = null; 
            if ( ConfigurationSettings.AppSettings[ "CMSCSSVirtualPath" ] == null ) { 
                appPath = HttpContext.Current.Request.ApplicationPath; 
                if ( !( appPath.EndsWith( "/" ) ) ) { 
                    appPath += "/"; 
                } 
                cssfile = appPath + "main.css"; 
            } 
            else { 
                cssfile = ConfigurationSettings.AppSettings[ "CMSCSSVirtualPath" ]; 
            } 
            
            result = @"<link href=""" + HttpContext.Current.Server.HtmlEncode( cssfile ) + @""" type=""text/css"" rel=""stylesheet"">" + Constants.vbCrLf; 
            return result; 
        } 
        
        
        
        ///<summary>Returns page title tag, meta tag "description" and meta tag "keywords" (applicable only on page templates).</summary>
        ///<param name="defaultAliasPath">Default alias path that is used when no aliaspath parameter is provided in the querystring.</param>        
        public static string GetPageTags( string defaultAliasPath ) { 
            return Functions.GetPageTitleTag( defaultAliasPath ) + Constants.vbCrLf + Functions.GetPageMetaKeyWordsTag( defaultAliasPath ) + Constants.vbCrLf + Functions.GetPageMetaDescriptionTag( defaultAliasPath ) + Constants.vbCrLf + Functions.GetCSSFileLink( defaultAliasPath ); 
        } 
        
        
        
        ///<summary>Returns DataRow containing page template information.</summary>
        ///<param name="aliasPath">Current alias path.</param>
        public static DataRow GetPageInfoDR( string aliasPath ) { 
            object[,] paramsIdent = new object[ 1, 3 ]; 
            DataSet ds = null; 
            GeneralConnection cn = null; 
            int cacheMinutes = 0; 
            DataRow dr = null; 
            
            // get the full path if multilingual support is used
            if ( ( ConfigurationSettings.AppSettings[ "CMSUseMultilingualSupport" ] + "" ).ToLower().Trim() == "true" ) { 
                if ( aliasPath == "/" ) { 
                    aliasPath = "/" + GetPreferredCulture(); 
                } 
                else { 
                    aliasPath = "/" + GetPreferredCulture() + aliasPath; 
                } 
            } 
            // try to find value in cache
            if ( HttpContext.Current.Cache[ "cmspageinfo_" + aliasPath.ToLower() ] == null ) { 
                // read data from database
                cn = new GeneralConnection( GetConnectionString() ); 
                paramsIdent[ 0, 0 ] = "@AliasPath"; 
                paramsIdent[ 0, 1 ] = ConfigurationSettings.AppSettings[ "CMSWebSiteBaseAliasPath" ] + aliasPath; 
                ds = cn.ExecuteQuery( "cms.menuitem.selectmenuitemfromaliaspath", paramsIdent ); 
                if ( ds.Tables[ 0 ].Rows.Count > 0 ) { 
                    if ( !( ConfigurationSettings.AppSettings[ "CMSCachePageInfoMinutes" ] == null ) ) { 
                        cacheMinutes = int.Parse( ConfigurationSettings.AppSettings[ "CMSCachePageInfoMinutes" ] ); 
                    } 
                    else { 
                        cacheMinutes = 0; 
                    } 
                    HttpContext.Current.Cache.Insert( "cmspageinfo_" + aliasPath.ToLower(), ds.Tables[ 0 ].Rows[ 0 ], null, DateAndTime.Now.AddMinutes( cacheMinutes ), System.Web.Caching.Cache.NoSlidingExpiration); 
                } 
                if ( ds.Tables[ 0 ].Rows.Count > 0 ) { 
                    dr = ds.Tables[ 0 ].Rows[ 0 ]; 
                } 
            } 
            else { 
                dr = ( ( DataRow )( HttpContext.Current.Cache[ "cmspageinfo_" + aliasPath.ToLower() ] ) ); 
            } 
            return dr; 
        } 
        
        
        
        ///<summary>Returns provided path without culture code.</summary>
        ///<param name="path">Path to be modified.</param>
        public static string RemoveCultureFromPath( object path ) { 
            string result = null; 
			string pth;
			if (path != null)
			{
				pth = path.ToString();
			}
			else
			{
				pth = "";
			}
            if ( Strings.Trim( Strings.LCase( ConfigurationSettings.AppSettings[ "CMSUseMultilingualSupport" ] + "" ) ) == "true" ) { 
                result = pth.Substring( pth.Split( '/' )[ 1 ].Length + 1 ); 
            } 
            else { 
                result = pth; 
            } 
            return result; 
        } 
        
		/// <summary>Encodes URL(just redirection for use with aspx code</summary>
		/// <param name="url">URL to encode</param>
		public static string UrlPathEncode(object url)
		{
			string path;
			if (url!=null)
			{
				path=url.ToString();
			}
			else
			{
				path="";
			}
			return HttpContext.Current.Server.UrlPathEncode(path);
		}
        
        
        ///<summary>Returns preferred culture code (as string). You can modify this function so that it determines the preferred culture using some other algorithm.</summary>
        public static string GetPreferredCulture() { 
            if ( HttpContext.Current.Session[ "CMSPreferredCulture" ] == null ) { 
                HttpContext.Current.Session[ "CMSPreferredCulture" ] = ConfigurationSettings.AppSettings[ "CMSDefaultCultureCode" ]; 
            } 
            return System.Convert.ToString( HttpContext.Current.Session[ "CMSPreferredCulture" ] ); 
        } 
        
        
        
        ///<summary>Returns type (such as "cms.article") of the current document.</summary>
        public static string GetDocumentType() { 
            if ( Strings.Trim( HttpContext.Current.Request.QueryString[ "aliaspath" ] + "" ) + "" == "" ) { 
                return ""; 
            } 
            else { 
                return GetDocumentType( Strings.Trim( HttpContext.Current.Request.QueryString[ "aliaspath" ] + "" ) ); 
            } 
        } 
        
        
        
        ///<summary>Returns type (such as "cms.article") of the specified document.</summary>
        ///<param name="aliasPath">Alias path of the document.</param>
        public static string GetDocumentType( string aliasPath ) { 
            TreeProvider tree = null; 
            TreeNode node = null; 
            
            if ( Strings.Trim( aliasPath + "" ) + "" == "" ) { 
                return GetDocumentType( "/" ); 
            } 
            else { 
                // get the full path if multilingual support is used
                if ( ( ConfigurationSettings.AppSettings[ "CMSUseMultilingualSupport" ] + "" ).ToLower().Trim() == "true" ) { 
                    if ( aliasPath == "/" ) { 
                        aliasPath = "/" + GetPreferredCulture(); 
                    } 
                    else { 
                        aliasPath = "/" + GetPreferredCulture() + aliasPath; 
                    } 
                } 
                
                tree = GetTreeProvider(); 
                node = tree.SelectSingleNode( aliasPath, TreePathTypeEnum.AliasPath ); 
                if ( node == null ) { 
                    return ""; 
                } 
                else { 
                    return node.ClassName; 
                } 
            } 
        } 
        
        
        
        ///<summary>Returns node representing the current page (the nearest parent page).</summary>
        public static TreeNode GetCurrentPage() { 
            DataRow dr = Functions.GetPageInfoDR( Functions.GetAliasPath() ); 
            return Functions.GetTreeProvider().SelectSingleNode( System.Convert.ToString( dr[ "AliasPath" ] ), TreePathTypeEnum.AliasPath, "cms.menuitem" ); 
        } 
        
        
        
        ///<summary>Returns node representing the current document.</summary>
        public static TreeNode GetCurrentDocument() { 
            string aliasPath = Functions.GetAliasPath(); 
            if ( aliasPath == null || aliasPath + "" == "" ) { 
                aliasPath = "/"; 
            } 
            
            // get the full path if multilingual support is used
            if ( ( ConfigurationSettings.AppSettings[ "CMSUseMultilingualSupport" ] + "" ).ToLower().Trim() == "true" ) { 
                if ( aliasPath == "/" ) { 
                    aliasPath = "/" + GetPreferredCulture(); 
                } 
                else { 
                    aliasPath = "/" + GetPreferredCulture() + aliasPath; 
                } 
            } 
            
            // get the node
            return Functions.GetTreeProvider().SelectSingleNode( aliasPath, TreePathTypeEnum.AliasPath ); 
        } 
        
        
        
        ///<summary>Returns true if the current user is member of the given role.</summary>
        ///<param name="roleName">Role name.</param>
        public static bool IsInRole( string roleName ) { 
            TreeSecurityProvider treeSec = new TreeSecurityProvider( Functions.GetTreeProvider() ); 
            return treeSec.IsInRole( roleName, Functions.GetUserID() ); 
        } 
        
        
        
        ///<summary>Writes event to the event log.</summary>
        ///<param name="eventType">Type of the event. I = information, E = error, W = warning</param>
        ///<param name="source">Source of the event (Content, Administration, etc.)</param>
        ///<param name="eventCode">Event code (Security, Update, Delete, etc.)</param>
        ///<param name="nodeId">ID value of the document.</param>
        ///<param name="nodeNamePath">NamePath value of the document.</param>
        ///<param name="eventDescription">Detailed description of the event.</param>
        public static void LogEvent( string eventType, string source, string eventCode, int nodeId, string nodeNamePath, string eventDescription ) { 
            TreeProvider tree = new TreeProvider( 0, new GeneralConnection( Functions.GetConnectionString() ) ); 
            Kentico.CMS.EventLog.EventLogProvider log = new Kentico.CMS.EventLog.EventLogProvider( tree.Connection ); 
            log.LogEvent( eventType, DateAndTime.Now, source, eventCode, 0, HttpContext.Current.User.Identity.Name, nodeId, nodeNamePath, HttpContext.Current.Request.UserHostAddress, eventDescription ); 
        } 
        
        
        
        ///<summary>Adds the postfix of the generated URLs according to the CMSFriendlyURLStyle web.config parameter value.</summary>
        ///<param name="path">Path to which the extension should be added.</param>
        public static string AddUrlExtension( string path ) { 
            if ( ( !( ConfigurationSettings.AppSettings[ "CMSFriendlyURLStyle" ] == null ) ) && ConfigurationSettings.AppSettings[ "CMSFriendlyURLStyle" ].Trim().ToLower()+ "" != "" ) { 
                if ( path == "/" | path == "~" | path == "~/" | path == "~/." ) { 
                    return path; 
                } 
                else { 
                    return path + ConfigurationSettings.AppSettings[ "CMSFriendlyURLStyle" ].Trim().ToLower(); 
                } 
            } 
            else { 
                return path; 
            } 
        } 
        
        
        
        ///<summary>Returns URL of the document specified by alias path.</summary>
        ///<param name="aliasPath">Alias path of the document.</param>
        public static string GetUrl( object aliasPath ) { 
            string url = null; 
            if ( aliasPath == null ) { 
                url = "/"; 
            } 
            else { 
                url = System.Convert.ToString( aliasPath ); 
            } 
            url = Functions.RemoveCultureFromAliasPath( url ); 
            url = Functions.AddUrlExtension( url ); 
            if ( HttpContext.Current.Request.ApplicationPath.EndsWith( "/" ) ) { 
                url = HttpContext.Current.Request.ApplicationPath.Substring( 0, HttpContext.Current.Request.ApplicationPath.Length - 1 ) + url; 
            } 
            else { 
                url = HttpContext.Current.Request.ApplicationPath + url; 
            } 
            return HttpContext.Current.Server.UrlPathEncode( url ); 
        } 
        
        
        
        ///<summary>Returns URL of the file document specified by alias path.</summary>
        ///<param name="aliasPath">Alias path of the file document.</param>
        public static string GetFileUrl( object aliasPath ) { 
            string url = "getfile.aspx"; 
            if ( HttpContext.Current.Request.ApplicationPath.EndsWith( "/" ) ) { 
                url = HttpContext.Current.Request.ApplicationPath + url; 
            } 
            else { 
                url = HttpContext.Current.Request.ApplicationPath + "/" + url; 
            } 
            url = url + "?aliaspath=" + Functions.RemoveCultureFromAliasPath( System.Convert.ToString( aliasPath ) ); 
            return HttpContext.Current.Server.UrlPathEncode( url ); 
        } 
        
        
        
        ///<summary>Returns link to the file with specified virtual path.</summary>
        ///<param name="filePath">Virtual path of the file, such as /products/nokia/nokia_large.gif.</param>
        public static string GetUrlForFilePath( object filePath ) { 
            string url = "getfile.aspx"; 
            if ( HttpContext.Current.Request.ApplicationPath.EndsWith( "/" ) ) { 
                url = HttpContext.Current.Request.ApplicationPath + url; 
            } 
            else { 
                url = HttpContext.Current.Request.ApplicationPath + "/" + url; 
            } 
            url = url + "?filepath=" + filePath; 
            return HttpContext.Current.Server.UrlPathEncode( url ); 
        } 
        
        
        
        ///<summary>Returns first N levels of the given alias path.</summary>
        ///<param name="aliasPath">Alias path.</param>
        ///<param name="level">Number of levels to be returned.</param>
        public static object GetPathLevel( string aliasPath, int level ) { 
            string resultPath = ""; 
            int i = 0; 
            string[] splitPath = null; 
            
            if ( aliasPath == null ) { 
                return ""; 
            } 
            splitPath = aliasPath.Split( '/' ); 
            for ( i=1; i<=level; i++ ) { 
                resultPath += "/" + splitPath[ i ]; 
            } 
            return resultPath; 
        } 
        
    } 
    
    
} 
