Imports Kentico.CMS.DataEngine
Imports Kentico.CMS.TreeEngine
Imports Kentico.CMS.Newsletter
Imports System.Text.RegularExpressions


Public Class NewsletterUnsubscribe
    Inherits System.Web.UI.Page

#Region " Web Form Designer Generated Code "

    'This call is required by the Web Form Designer.
    <System.Diagnostics.DebuggerStepThrough()> Private Sub InitializeComponent()

    End Sub

    Protected WithEvents lblInfo As System.Web.UI.WebControls.Label
    Protected WithEvents lblError As System.Web.UI.WebControls.Label

    'NOTE: The following placeholder declaration is required by the Web Form Designer.
    'Do not delete or move it.
    Private designerPlaceholderDeclaration As System.Object

    Private Sub Page_Init(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Init
        'CODEGEN: This method call is required by the Web Form Designer
        'Do not modify it using the code editor.
        InitializeComponent()
    End Sub

#End Region

    Private Sub Page_Load(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load
        Dim errorMessage As String
        Dim infoMessage As String

        Dim email As String
        Dim newsletterId As Integer
        Dim newsletterIssueId As Integer
        Dim subscriberId As Integer

        'Set initial value and label visibility.
        lblError.Text = ""
        lblError.Visible = False
        lblInfo.Text = ""
        lblInfo.Visible = False

        'Parsing posted values
        Try
            email = ParseEmail(Request.QueryString("email"))
        Catch ex As ArgumentNullException
            errorMessage &= Replace(ResMan.GetString("NewsletterUnsubscribe.ErrorMissingParameter"), "{%parameter%}", "Email") & " "
        Catch ex As Exception
            errorMessage &= Replace(ResMan.GetString("NewsletterUnsubscribe.ErrorInvalidParameter"), "{%parameter%}", "Email") & " "
        End Try
        Try
            newsletterId = Integer.Parse(Request.QueryString("newsletterid"))
        Catch ex As ArgumentNullException
            errorMessage &= Replace(ResMan.GetString("NewsletterUnsubscribe.ErrorMissingParameter"), "{%parameter%}", "NewsletterID") & " "
        Catch ex As Exception
            errorMessage &= Replace(ResMan.GetString("NewsletterUnsubscribe.ErrorInvalidParameter"), "{%parameter%}", "NewsletterID") & " "
        End Try
        Try
            subscriberId = Integer.Parse(Request.QueryString("subscriberid"))
        Catch ex As ArgumentNullException
            errorMessage &= Replace(ResMan.GetString("NewsletterUnsubscribe.ErrorMissingParameter"), "{%parameter%}", "SubscriberID") & " "
        Catch ex As Exception
            errorMessage &= Replace(ResMan.GetString("NewsletterUnsubscribe.ErrorInvalidParameter"), "{%parameter%}", "SubscriberID") & " "
        End Try

        If errorMessage = "" Then
            Dim manager As New NewsletterManager(Functions.GetTreeProvider)
            Dim connection As GeneralConnection = manager.TreeProvider.Connection
            Dim newsletter As DataClass
            Dim subscriber As DataClass
            Dim newsletterIssue As DataClass

            'Verify if newsletter is existing.
            newsletter = New DataClass("CMS.Newsletter", newsletterId, connection)
            If newsletter Is Nothing OrElse newsletter.IsEmpty = True Then
                errorMessage &= ResMan.GetString("NewsletterUnsubscribe.ErrorNonExistingNewsletter") & " "
            End If

            'Verify if subscriber is existing and valid.
            subscriber = manager.GetSubscriber(email)
            If subscriber Is Nothing OrElse subscriber.IsEmpty = True OrElse _
            subscriberId <> CInt(subscriber.GetValue("SubscriberId")) Then
                errorMessage &= ResMan.GetString("NewsletterUnsubscribe.ErrorNonExistingSubscriber") & " "
            End If

            Try
                newsletterIssueId = Integer.Parse(Request.QueryString("newsletterissueid"))
                'Verify if newsletter issue is existing.
                newsletterIssue = New DataClass("CMS.NewsletterIssue", newsletterIssueId, connection)
                If newsletterIssue Is Nothing OrElse newsletterIssue.IsEmpty = True Then
                    errorMessage &= ResMan.GetString("NewsletterUnsubscribe.ErrorNonExistingNewsletterIssue") & " "
                End If
            Catch
            End Try

            'Verify if subscription is existing.
            If errorMessage = "" Then
                Dim subscriptionParams(1, 2) As Object
                Dim subscription As DataSet

                subscriptionParams(0, 0) = "@SubscriberID"
                subscriptionParams(0, 1) = subscriberId
                subscriptionParams(1, 0) = "@NewsletterID"
                subscriptionParams(1, 1) = newsletterId
                subscription = connection.ExecuteQuery("cms.subscriber.checksubscription", subscriptionParams)

                If CInt(subscription.Tables(0).Rows(0)(0)) = 0 Then
                    errorMessage &= ResMan.GetString("NewsletterUnsubscribe.ErrorNonExistingSubscription") & " "
                End If
            End If

            'Perform unsubscription.
            If errorMessage = "" Then
                'Begin transaction.
                connection.DataConnection.Open()
                connection.DataConnection.BeginTransaction()

                Try
                    Dim currentCount As Integer
                    If Not newsletterIssue Is Nothing Then
                        currentCount = CInt(newsletterIssue.GetValue("NewsletterUnsubscriptions"))
                    End If

                    'Delete the newsletter subscription.
                    manager.DeleteSubscription(newsletterId, subscriberId)

                    'Update unsubscription count.
                    If Not newsletterIssue Is Nothing Then
                        newsletterIssue.SetValue("NewsletterUnsubscriptions", currentCount + 1)
                        newsletterIssue.Update()
                    End If

                    'Commit transaction.
                    connection.DataConnection.CommitTransaction()

                    'Inform the user about the success.
                    infoMessage = ResMan.GetString("NewsletterUnsubscribe.SuccessfullyRemoved")
                Catch
                    'Rollback transaction.
                    connection.DataConnection.RollbackTransaction()
                    'Assign common description.
                    errorMessage &= ResMan.GetString("NewsletterUnsubscribe.ErrorAnErrorOccurred") & " "
                Finally
                    'Close data connection.
                    connection.DataConnection.Close()
                End Try
            End If
        End If

            'Display information about the operation.
            If errorMessage <> "" Then
                lblError.Text = errorMessage
                lblError.Visible = True
            End If
            If infoMessage <> "" Then
                lblInfo.Text = infoMessage
                lblInfo.Visible = True
            End If
    End Sub

    '''<summary>Converts a string to valid e-mail address.</summary>
    '''<param name="value">A string to convert</param>
    Private Shared Function ParseEmail(ByVal value As String) As String
        If value Is Nothing Then Throw New ArgumentNullException("value")

        If Regex.IsMatch(value, "^\s*[a-zA-Z0-9]([_\.\-]?[a-zA-Z0-9]+)*@[a-zA-Z0-9]([\.\-]?[a-zA-Z0-9]+)*\.[a-zA-Z]{2,6}\s*$") = False Then
            Throw New FormatException("Input value has an invalid format.")
        End If
        Return value.Trim()
    End Function
End Class
